<?php

/*
Plugin Name: Image Widget
Plugin URI: http://wordpress.org/extend/plugins/image-widget/
Description: A simple image widget that uses the native WordPress media manager to add image widgets to your site.
Author: Modern Tribe, Inc.
Version: 4.2.2
Author URI: http://m.tri.be/26
*/

class St_Adamas_Banner_Widget extends WP_Widget {
	function __construct() {
		$widget_ops = array( 'description' => esc_html__( 'Displays image banner.', 'adamas-custom-widgets' ) );
		parent::__construct( 'st_banner_widget', esc_html__( 'Banner', 'adamas-custom-widgets' ), $widget_ops );

		add_action( 'sidebar_admin_setup', array( $this, 'st_adamas_banner_admin_setup' ) );
	}

	function st_adamas_banner_admin_setup() {
		wp_enqueue_media();
		wp_enqueue_script( 'st-adamas-banner-widget', get_template_directory_uri() . '/assets/js/banner-widget.js', array(
			'jquery',
			'media-upload',
			'media-views'
		), true );

		wp_localize_script( 'st-adamas-banner-widget', 'BannerWidget', array(
			'frame_title'  => esc_html__( 'Select an Image', 'adamas-custom-widgets' ),
			'button_title' => esc_html__( 'Insert Into Widget', 'adamas-custom-widgets' ),
		) );
	}

	function widget( $args, $instance ) {
		extract( $args );
		if ( ! empty( $instance['imageurl'] ) ) {
			$instance['title']      = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'] );
			$instance['link']       = apply_filters( 'image_widget_image_link', esc_url( $instance['link'] ), $args, $instance );
			$instance['linktarget'] = apply_filters( 'image_widget_image_link_target', esc_attr( $instance['linktarget'] ), $args, $instance );
			$instance['alt']        = apply_filters( 'image_widget_image_alt', esc_attr( $instance['alt'] ), $args, $instance );
			$instance['imageurl']   = apply_filters( 'image_widget_image_url', esc_url( $instance['imageurl'] ), $args, $instance );

			extract( $instance );

			echo $before_widget;
			if ( ! empty( $title ) ) {
				echo $before_title . $title . $after_title;
			}
			echo $this->get_image_html( $instance, true );
			echo $after_widget;

		}
	}

	function get_image_html( $instance, $include_link = true ) {
		$output = '';

		if ( $include_link && ! empty( $instance['link'] ) ) {
			$attr   = array(
				'href'   => esc_url( $instance['link'] ),
				'target' => $instance['linktarget'],
				'class'  => 'st-banner-link',
				'title'  => ( ! empty( $instance['alt'] ) ) ? strip_tags( $instance['alt'] ) : $instance['title'],
			);
			$attr   = apply_filters( 'image_widget_link_attributes', $attr, $instance );
			$attr   = array_map( 'esc_attr', $attr );
			$output = '<a';
			foreach ( $attr as $name => $value ) {
				$output .= sprintf( ' %s="%s"', $name, $value );
			}
			$output .= '>';
		}

		if ( ! empty( $instance['imageurl'] ) ) {
			$img_attr = array(
				'src' => esc_url( $instance['imageurl'] ),
				'alt' => ( ! empty( $instance['alt'] ) ) ? strip_tags( $instance['alt'] ) : $instance['title'],
			);
			$img_attr = array_map( 'esc_attr', $img_attr );
			$output   .= "<img";
			foreach ( $img_attr as $name => $value ) {
				$output .= sprintf( ' %s="%s"', $name, $value );
			}
			$output .= ' />';
		}

		if ( $include_link && ! empty( $instance['link'] ) ) {
			$output .= '</a>';
		}

		return $output;
	}

	function update( $new_instance, $old_instance ) {
		$instance               = $old_instance;
		$instance['title']      = strip_tags( $new_instance['title'] );
		$instance['link']       = $new_instance['link'];
		$instance['linktarget'] = $new_instance['linktarget'];
		$instance['alt']        = $new_instance['alt'];
		$instance['imageurl']   = $new_instance['imageurl'];

		return $instance;
	}

	function form( $instance ) {
		$id_prefix = $this->get_field_id( '' );

		if ( ! isset( $instance['link'] ) ) {
			$instance['link'] = '';
		}
		if ( ! isset( $instance['alt'] ) ) {
			$instance['alt'] = '';
		}
		if ( ! isset( $instance['linktarget'] ) ) {
			$instance['linktarget'] = '';
		}
		if ( ! isset( $instance['title'] ) ) {
			$instance['title'] = '';
		}
		if ( ! isset( $instance['imageurl'] ) ) {
			$instance['imageurl'] = '';
		}

		?>
        <div class="st-widget-banner-uploader">
            <input type="submit" class="button"
                   name="<?php echo esc_attr( $this->get_field_name( 'uploader_button' ) ); ?>"
                   id="<?php echo esc_attr( $this->get_field_id( 'uploader_button' ) ); ?>"
                   value="<?php esc_attr_e( 'Select an Image', 'adamas-custom-widgets' ); ?>"
                   onclick="BannerWidget.uploader( '<?php echo esc_attr( $this->id ); ?>', '<?php echo esc_attr( $id_prefix ); ?>' ); return false;"/>
            <div class="st_image_preview" id="<?php echo esc_attr( $this->get_field_id( 'preview' ) ); ?>">
				<?php echo $this->get_image_html( $instance, false ); ?>
            </div>
            <input type="hidden" id="<?php echo esc_attr( $this->get_field_id( 'imageurl' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'imageurl' ) ); ?>"
                   value="<?php echo esc_url( $instance['imageurl'] ); ?>"/>
        </div>
        <br clear="all"/>

        <div id="<?php echo esc_attr( $this->get_field_id( 'fields' ) ); ?>"
		     <?php if ( empty( $instance['imageurl'] ) ) { ?>style="display:none;"<?php } ?>>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'adamas-custom-widgets' ); ?>
                    :</label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
                       name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text"
                       value="<?php echo esc_attr( strip_tags( $instance['title'] ) ); ?>"/></p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'alt' ) ); ?>"><?php esc_html_e( 'Alternate Text', 'adamas-custom-widgets' ); ?>
                    :</label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'alt' ) ); ?>"
                       name="<?php echo esc_attr( $this->get_field_name( 'alt' ) ); ?>" type="text"
                       value="<?php echo esc_attr( strip_tags( $instance['alt'] ) ); ?>"/></p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>"><?php esc_html_e( 'Link', 'adamas-custom-widgets' ); ?>
                    :</label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>"
                       name="<?php echo esc_attr( $this->get_field_name( 'link' ) ); ?>" type="text"
                       value="<?php echo esc_attr( strip_tags( $instance['link'] ) ); ?>"/><br/>
                <select name="<?php echo esc_attr( $this->get_field_name( 'linktarget' ) ); ?>"
                        id="<?php echo esc_attr( $this->get_field_id( 'linktarget' ) ); ?>">
                    <option value="_self"<?php selected( $instance['linktarget'], '_self' ); ?>><?php esc_html_e( 'Stay in Window', 'adamas-custom-widgets' ); ?></option>
                    <option value="_blank"<?php selected( $instance['linktarget'], '_blank' ); ?>><?php esc_html_e( 'Open New Window', 'adamas-custom-widgets' ); ?></option>
                </select></p>
        </div>
		<?php
	}
}

add_action( 'widgets_init', function () {
	register_widget( 'St_Adamas_Banner_Widget' );
} );