<?php

class St_Adamas_Projects_Widget extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'classname'   => 'widget_projects',
			'description' => esc_html__( 'Displays projects.', 'adamas-custom-widgets' ),
		);
		parent::__construct( 'projects', esc_html__( 'Projects', 'adamas-custom-widgets' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number ) {
			$number = 6;
		}

		$r = new WP_Query( array(
			'post_type'      => 'projects',
			'posts_per_page' => $number,
		) );

		if ( $r->have_posts() ) :
			?>
			<?php echo $args['before_widget']; ?>
			<?php if ( $title ) {
			echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
		} ?>
            <ul>
				<?php while ( $r->have_posts() ) : $r->the_post(); ?>

					<?php
					$image_url = wp_get_attachment_url( get_post_thumbnail_id(), 'full' );
					$image     = st_adamas_aq_resize( $image_url, 150, 150, true, true, true );
					?>

                    <li>
						<?php if ( $image ) { ?>
                            <div class="st-project-thumbnail"><a href="<?php the_permalink(); ?>">
                                    <div class="st-overlay"></div>
                                    <img src="<?php echo esc_url( $image ); ?>"
                                         alt="<?php get_the_title() ? the_title() : the_ID(); ?>"/></a></div>
						<?php } ?>
                    </li>
				<?php endwhile; ?>
            </ul>
			<?php echo $args['after_widget']; ?>
			<?php
			// Reset the global $the_post as this query will have stomped on it
			wp_reset_postdata();

		endif;
	}

	function update( $new_instance, $old_instance ) {
		$instance           = $old_instance;
		$instance['title']  = sanitize_text_field( $new_instance['title'] );
		$instance['number'] = (int) $new_instance['number'];

		return $instance;
	}

	function form( $instance ) {
		$title  = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'adamas-custom-widgets' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text"
                   value="<?php echo esc_attr( $title ); ?>"/></p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'adamas-custom-widgets' ); ?></label>
            <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1"
                   value="<?php echo esc_attr( $number ); ?>" size="3"/></p>
		<?php
	}
}

add_action( 'widgets_init', function () {
	register_widget( 'St_Adamas_Projects_Widget' );
} );

?>