<?php

class St_Adamas_Recent_Posts_Widget extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'classname'                   => 'widget_recent_entries',
			'description'                 => esc_html__( 'Your site&#8217;s most recent Posts.', 'adamas-custom-widgets' ),
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'recent-posts', esc_html__( 'Recent Posts', 'adamas-custom-widgets' ), $widget_ops );
		$this->alt_option_name = 'widget_recent_entries';
	}

	function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Recent Posts', 'adamas-custom-widgets' );

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number ) {
			$number = 5;
		}
		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

		$r = new WP_Query( apply_filters( 'widget_posts_args', array(
			'posts_per_page'      => $number,
			'no_found_rows'       => true,
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true
		) ) );

		if ( $r->have_posts() ) :
			?>
			<?php echo $args['before_widget']; ?>
			<?php if ( $title ) {
			echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
		} ?>
            <ul>
				<?php while ( $r->have_posts() ) : $r->the_post(); ?>

					<?php
					$image = wp_get_attachment_url( get_post_thumbnail_id(), 'full' );
					$image = st_adamas_aq_resize( $image, 80, 70, true, true, true );
					?>

                    <li>
						<?php if ( $image ) { ?>
                            <div class="post-thumbnail"><a href="<?php the_permalink(); ?>"><img
                                            src="<?php echo esc_url( $image ); ?>"
                                            alt="<?php echo esc_attr( get_the_title() ); ?>"/></a></div>
						<?php } ?>
                        <div class="post-inner">
                            <a href="<?php the_permalink(); ?>"><?php echo wp_trim_words( get_the_title(), 5, '...' ); ?></a>
							<?php if ( $show_date ) : ?>
                                <time class="post-date"
                                      datetime="<?php echo get_the_date( 'Y-m-d' ); ?>"><?php echo get_the_date( get_option( 'date_format' ) ); ?></time>
							<?php endif; ?>
                        </div>
                    </li>
				<?php endwhile; ?>
            </ul>
			<?php echo $args['after_widget']; ?>
			<?php
			// Reset the global $the_post as this query will have stomped on it
			wp_reset_postdata();

		endif;
	}

	function update( $new_instance, $old_instance ) {
		$instance              = $old_instance;
		$instance['title']     = sanitize_text_field( $new_instance['title'] );
		$instance['number']    = (int) $new_instance['number'];
		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;

		return $instance;
	}

	function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
		?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'adamas-custom-widgets' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text"
                   value="<?php echo esc_attr( $title ); ?>"/></p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'adamas-custom-widgets' ); ?></label>
            <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1"
                   value="<?php echo esc_attr( $number ); ?>" size="3"/></p>

        <p><input class="checkbox" type="checkbox"<?php checked( $show_date ); ?>
                  id="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>"
                  name="<?php echo esc_attr( $this->get_field_name( 'show_date' ) ); ?>"/>
            <label for="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>"><?php esc_html_e( 'Display post date?', 'adamas-custom-widgets' ); ?></label>
        </p>
		<?php
	}
}

add_action( 'widgets_init', function () {
	register_widget( 'St_Adamas_Recent_Posts_Widget' );
} );

?>