<?php

class St_Shop_Info_Widget extends WP_Widget {


	function __construct() {
		$widget_ops = array( 'description' => esc_html__( 'Displays infobox for shop.', 'adamas-custom-widgets' ) );
		parent::__construct( 'st_shop_info_widget', esc_html__( 'Shop info', 'adamas-custom-widgets' ), $widget_ops );
	}


	function widget( $args, $instance ) {
		extract( $args );
		$max_entries = 99;
		$title       = $before_title . apply_filters( 'widget_title', $instance['title'] ) . $after_title;
		echo $before_widget;
		if ( ! empty( $instance['title'] ) ) {
			echo esc_html( $title );
		}
		?>
        <div class="st-shop-info-widget-inner">
			<?php
			for ( $i = 0; $i < $max_entries; $i ++ ) {
				$block = $instance[ 'block-' . $i ];
				if ( isset( $block ) && $block != "" ) {
					//Image
					$image_url = esc_url( $instance[ 'image_uri-' . $i ] );
					$image     = '<img src="' . $image_url . '" alt="' . esc_attr( $instance[ 'box_title-' . $i ] ) . '" />';

					?>

                    <div class="st-shop-info-widget-item">
                        <div class="st-shop-info-icon"><?php echo $image; ?></div>
                        <div class="st-shop-info-widget-item-inner">
                            <div class="st-shop-info-title"><?php echo esc_html( $instance[ 'box_title-' . $i ] ); ?></div>
                            <div class="st-shop-info-widget-text" id="text-full<?php echo esc_attr( $i ); ?>"><?php echo apply_filters( 'the_content', $instance[ 'text-' . $i ] ); ?></div>
                        </div>
                    </div>
				<?php }
			} ?>
        </div>
		<?php echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance          = array();
		$max_entries       = 99;
		$instance['title'] = strip_tags( $new_instance['title'] );
		for ( $i = 0; $i < $max_entries; $i ++ ) {
			$block = $new_instance[ 'block-' . $i ];
			if ( $block == 0 || $block == "" ) {
				$instance[ 'block-' . $i ]     = $new_instance[ 'block-' . $i ];
				$instance[ 'image_uri-' . $i ] = esc_url( $new_instance[ 'image_uri-' . $i ] );
				$instance[ 'box_title-' . $i ] = strip_tags( $new_instance[ 'box_title-' . $i ] );
				$instance[ 'text-' . $i ]      = strip_tags( $new_instance[ 'text-' . $i ] );
			} else {
				$count                             = $block - 1;
				$instance[ 'block-' . $count ]     = $new_instance[ 'block-' . $i ];
				$instance[ 'image_uri-' . $count ] = esc_url( $new_instance[ 'image_uri-' . $i ] );
				$instance[ 'box_title-' . $i ]     = strip_tags( $new_instance[ 'box_title-' . $i ] );
				$instance[ 'text-' . $count ]      = strip_tags( $new_instance[ 'text-' . $i ] );
			}
		}

		return $instance;
	}


	function form( $instance ) {
		$max_entries = 99;
		if ( ! isset( $instance['title'] ) ) {
			$instance['title'] = '';
		}

		$widget_add_id = $this->id . "-add";
		$title         = esc_attr( $instance['title'] );

		$output = '<p>';
		$output .= '<label for="' . esc_attr( $this->get_field_id( 'title' ) ) . '">' . esc_html__( 'Widget Title', 'adamas-custom-widgets' ) . ':</label>';
		$output .= '<input id="' . esc_attr( $this->get_field_id( 'title' ) ) . '" name="' . esc_attr( $this->get_field_name( 'title' ) ) . '" type="text" value="' . esc_attr( $title ) . '" />';
		$output .= '<div class="' . esc_attr( $widget_add_id ) . '-input-containers"><div id="entries">';
		for ( $i = 0; $i < $max_entries; $i ++ ) {

			if ( ! isset( $instance[ 'block-' . $i ] ) ) {
				$instance[ 'block-' . $i ] = '';
			}
			if ( ! isset( $instance[ 'image_uri-' . $i ] ) ) {
				$instance[ 'image_uri-' . $i ] = '';
			}
			if ( ! isset( $instance[ 'box_title-' . $i ] ) ) {
				$instance[ 'box_title-' . $i ] = '';
			}
			if ( ! isset( $instance[ 'text-' . $i ] ) ) {
				$instance[ 'text-' . $i ] = '';
			}

			$block     = esc_attr( $instance[ 'block-' . $i ] );
			$image_uri = $instance[ 'image_uri-' . $i ];
			$box_title = esc_attr( $instance[ 'box_title-' . $i ] );
			$text      = esc_attr( $instance[ 'text-' . $i ] );

			$display = ( ! isset( $instance[ 'block-' . $i ] ) || ( $instance[ 'block-' . $i ] == "" ) ) ? 'style="display:none;"' : '';
			if ( $display ) {
				unset( $instance );
			}

			$output .= '<div id="entry' . ( $i + 1 ) . '" ' . $display . ' class="entrys"><span class="entry-title" onclick = "slider(this);">' . esc_html__( 'Info box', 'adamas-custom-widgets' ) . '</span>';
			$output .= '<div class="entry-desc cf">';
			$output .= '<input id="' . esc_attr( $this->get_field_id( 'block-' . $i ) ) . '" name="' . esc_attr( $this->get_field_name( 'block-' . $i ) ) . '" type="hidden" value="' . $block . '">';

			// Client Image
			$output .= '<p>';
			$output .= '<label for="' . esc_attr( $this->get_field_id( 'image_uri-' . $i ) ) . '">' . esc_html__( 'Image', 'adamas-custom-widgets' ) . ':</label>';
			$show   = ( ! empty( $image_uri ) ) ? 'style="display:block;"' : '';
			$output .= '<input type="button" name="removeimg" id="remove-img" class="button button-secondary" onclick="removeImage(' . $i . ');" ' . $show . '>';
			$output .= '<img src="' . esc_url( $image_uri ) . '" class="block-image" ' . $show . '>';
			$output .= '<input type="hidden" class="img' . $i . '" style="width:auto;" name="' . esc_attr( $this->get_field_name( 'image_uri-' . $i ) ) . '" id="' . esc_attr( $this->get_field_id( 'image_uri-' . $i ) ) . '" value="' . esc_attr( $image_uri ) . '" />';
			$output .= '<input type="button" class="select-img' . $i . '" style="width:auto;" value="Select Image" onclick="selectImage(' . $i . ');"/>';
			$output .= '</p>';

			// Client name
			$output .= '<p>';
			$output .= '<label for="' . esc_attr( $this->get_field_id( 'box_title-' . $i ) ) . '">' . esc_html__( 'Box title', 'adamas-custom-widgets' ) . ':</label>';
			$output .= '<input type="text" name="' . esc_attr( $this->get_field_name( 'box_title-' . $i ) ) . '" id="' . esc_attr( $this->get_field_id( 'box_title-' . $i ) ) . '" value="' . $box_title . '" />';
			$output .= '</p>';

			// Client Comment
			$output .= '<p class="last desc">';
			$output .= '<label for="' . esc_attr( $this->get_field_id( 'text-' . $i ) ) . '">' . esc_html__( 'Info text', 'adamas-custom-widgets' ) . ':</label>';
			$output .= '<textarea id="' . esc_attr( $this->get_field_id( 'text-' . $i ) ) . '" name="' . esc_attr( $this->get_field_name( 'text-' . $i ) ) . '">' . $text . '</textarea>';
			$output .= '</p>';


			$output .= '<p><a href="#delete"><span class="delete-row">' . esc_html__( 'Delete Row', 'adamas-custom-widgets' ) . '</span></a></p>';
			$output .= '</div></div>';
		}
		$output .= '</div></div>';
		$output .= '<div id="message">Sorry, you reached to the limit of "' . esc_attr( $max_entries ) . '" maximum entries.</div>';
		$output .= '<div class="' . esc_attr( $widget_add_id ) . '" style="display:none;">' . esc_html__( 'ADD INFO BOX', 'adamas-custom-widgets' ) . '</div>';
		?>
        <script>
          jQuery(document).ready(function(e) {
            jQuery.each(jQuery(".<?php echo esc_js( $widget_add_id ); ?>-input-containers #entries").children(), function() {
              if (jQuery(this).find('input').val() !== '') {
                jQuery(this).show();
              }
            });
            jQuery(".<?php echo esc_js( $widget_add_id ); ?>").bind('click', function(e) {
              var rows = 0;
              jQuery.each(jQuery(".<?php echo esc_js( $widget_add_id ); ?>-input-containers #entries").children(), function() {
                if (jQuery(this).find('input').val() === '') {
                  jQuery(this).find('.entry-title').addClass('active');
                  jQuery(this).find('.entry-desc').slideDown();
                  jQuery(this).find('input').first().val('0');
                  jQuery(this).show();
                  return false;
                } else {
                  rows++;
                  jQuery(this).show();
                  jQuery(this).find('.entry-title').removeClass('active');
                  jQuery(this).find('.entry-desc').slideUp();
                }
              });
              if (rows == '<?php echo esc_js( $max_entries );?>') {
                jQuery('#st-widget-container #message').show();
              }
            });
            jQuery('.delete-row').bind('click', function(e) {
              var count = 1;
              var current = jQuery(this).closest('.entrys').attr('id');
              jQuery.each(jQuery('#entries #' + current + ' .entry-desc').children(), function() {
                jQuery(this).val('');
              });
              jQuery.each(jQuery('#entries #' + current + ' .entry-desc p').children(), function() {
                jQuery(this).val('');
              });
              jQuery('#entries #' + current + ' .entry-title').removeClass('active');
              jQuery('#entries #' + current + ' .entry-desc').hide();
              jQuery('#entries #' + current).remove();
              jQuery.each(jQuery(".<?php echo esc_js( $widget_add_id ); ?>-input-containers #entries").children(), function() {
                if (jQuery(this).find('input').val() !== '') {
                  jQuery(this).find('input').first().val(count);
                }
                count++;
              });
            });
          });
        </script>
        <style>
            .cf:before, .cf:after {
                content: "";
                display: table;
            }

            .cf:after {
                clear: both;
            }

            .cf {
                zoom: 1;
            }

            .clear {
                clear: both;
            }

            .clearfix:after {
                content: ".";
                display: block;
                height: 0;
                clear: both;
                visibility: hidden;
            }

            .clearfix {
                display: inline-block;
            }

            * html .clearfix {
                height: 1%;
            }

            .clearfix {
                display: block;
            }

            #st-widget-container input {
                float: right;
                width: 60%;
            }

            #st-widget-container label {
                width: 40%;
            }

            <?php echo '.'.$widget_add_id; ?>
            {
                background: #ccc none repeat scroll 0 0
            ;
                font-weight: bold
            ;
                margin: 20px 0px 9px
            ;
                padding: 6px
            ;
                text-align: center
            ;
                display: block !important
            ;
                cursor: pointer
            ;
            }
            .block-image {
                width: 50px;
                height: 30px;
                float: right;
                display: none;
            }

            .desc {
                height: 55px;
            }

            #entries #remove-img {
                background: url('<?php echo get_template_directory_uri().'/assets/images/deleteimg.png'; ?>') center center no-repeat;
                width: 20px;
                height: 22px;
                display: none;
            }

            /* TODO : Add deleteimg */
            #entries {
                padding: 10px 0 0;
            }

            #entries .entrys {
                padding: 0;
                border: 1px solid #e5e5e5;
                margin: 10px 0 0;
                clear: both;
            }

            #entries .entrys:first-child {
                margin: 0;
            }

            #entries .delete-row {
                margin-top: 20px;
                float: right;
                text-decoration: underline;
                color: red;
            }

            #entries .entry-title {
                display: block;
                font-size: 14px;
                line-height: 18px;
                font-weight: 600;
                background: #f1f1f1;
                padding: 7px 5px;
                position: relative;
            }

            #entries .entry-title:after {
                content: '\f140';
                font: 400 20px/1 dashicons;
                position: absolute;
                right: 10px;
                top: 6px;
                color: #a0a5aa;
            }

            #entries .entry-title.active:after {
                content: '\f142';
            }

            #entries .entry-desc {
                display: none;
                padding: 0 10px 10px;
                border-top: 1px solid #e5e5e5;
            }

            #st-widget-container #entries p.last label {
                white-space: pre-line;
                float: left;
                width: 39%;
            }

            #message {
                padding: 6px;
                display: none;
                color: red;
                font-weight: bold;
            }
        </style>
        <div id="st-widget-container">
			<?php echo $output; ?>
        </div>
		<?php
	} //Function form ends here
} //REW_Plugin class ends here

add_action( 'widgets_init', function () {
	register_widget( 'St_Shop_Info_Widget' );
} );

/**
 * Function to add widget script at admin side
 */
function st_shop_info_widget_admin_enqueue() {
	wp_enqueue_style( 'thickbox' );
	wp_enqueue_script( 'media-upload' );
	wp_enqueue_script( 'thickbox' );
	wp_enqueue_script( 'st-widget-repeater', plugins_url( 'js/widget-repeater.js', __FILE__ ), false, null, false );
}

add_action( 'admin_enqueue_scripts', 'st_shop_info_widget_admin_enqueue' );