<?php
/*
  Plugin Name: Adamas VC Shortcodes
  Plugin URI: https://slimtemplate.net/
  Description: Adamas Theme Custom VC Shortcodes
  Version: 1.0.4
  Author: SlimTemplate
  Text Domain: adamas-vc-shortcodes
  Domain Path: /lang/
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Adamas_VC_Shortcodes' ) ) {

	class Adamas_VC_Shortcodes {

		private $custom_modules;

		public function __construct() {



			if ( ! class_exists( 'Vc_Manager' ) || ! class_exists( 'Ultimate_VC_Addons' ) ) {
				add_action( 'admin_init', array( $this, 'vc_activation_check' ) );

				return;
			}

			// Translations
			add_action( 'init', array( $this, 'plugin_load_textdomain' ), 10 );

			$this->custom_modules = array(
				'st_addresses_map',
				'st_advanced_blockquote',
				'st_advanced_single_image',
				'st_advantage_block',
				'st_advantage_box',
				'st_award_block',
				'st_blockquote',
				'st_brands',
				'st_identity_block',
				'st_image_slider',
				'st_info_block',
				'st_info_boxes',
				'st_page_navigation',
				'st_pages_grid',
				'st_partners',
				'st_partners_block',
				'st_product_carousel',
				'st_product_promo',
				'st_projects_portfolio',
				'st_service_box',
				'st_shop_info_block',
				'st_simple_page_block',
				'st_simple_contact_box',
				'st_simple_price_box',
				'st_single_project',
				'st_single_service',
				'st_single_social',
				'st_social_buttons',
				'st_team_member_block',
				'st_team_member_info',
				'st_testimonials',
				'st_vacancy_table',
				'st_vertical_carousel',
				'st_vertical_text_block',
				'ultimate_headings',
				'ultimate_info_box',
				'ultimate_pricing_tables',
				'ultimate_stats_counter',
				'ultimate_tab',
			);

			foreach ( $this->custom_modules as $module_file ) {
				$module_file_path = plugin_dir_path( __FILE__ ) . '/includes/shortcodes/' . $module_file . '.php';
				if ( file_exists( $module_file_path ) ) {
					require_once $module_file_path;
				}
			}

			require_once plugin_dir_path( __FILE__ ) . '/includes/vc_settings.php';

			// Update modules option
			add_action( 'update_option_ultimate_modules', array( $this, 'update_uvc_modules' ), 999, 2 );

		}

		public function plugin_load_textdomain() {

			load_plugin_textdomain( 'adamas-vc-shortcodes', false, basename( dirname( __FILE__ ) ) . '/lang/' );

		}

		public function vc_activation_check() {

			add_action( 'admin_notices', array( $this, 'admin_notice_vc_activation' ) );
			add_action( 'network_admin_notices', array( $this, 'admin_notice_vc_activation' ) );

		}

		public function admin_notice_vc_activation() {

			$is_multisite = is_multisite();
			if ( ! $is_multisite || ( $is_multisite && is_network_admin() ) ) {

				$vc_not_active  = ! class_exists( 'Vc_Manager' );
				$uvc_not_active = ! class_exists( 'Ultimate_VC_Addons' );

				$message = __( 'Adamas VC shortcodes add-on requires ', 'adamas-vc-shortcodes' );

				if ( $vc_not_active ) {
					$message .= __( 'WPBakery Page Builder', 'adamas-vc-shortcodes' );
				}

				if ( $vc_not_active && $uvc_not_active ) {
					$message .= __( ' and ', 'adamas-vc-shortcodes' );
				}

				if ( $uvc_not_active ) {
					$message .= __( 'Ultimate Addons for WPBakery Page Builder', 'adamas-vc-shortcodes' );
				}

				$message .= '.';

				echo '<div class="notice notice-warning"><p>' . $message . '</p></div>';
			}
		}

		public function update_uvc_modules( $old_value, $value ) {

			return array_merge( $value, $this->custom_modules );

		}

	}

}


add_action( 'plugins_loaded', 'st_adamas_vc_shortcodes_init' );

function st_adamas_vc_shortcodes_init() {

	new Adamas_VC_Shortcodes;

}


register_activation_hook( __FILE__, 'st_adamas_set_uvc_combined_css_js' );

function st_adamas_set_uvc_combined_css_js() {

	update_option( 'ultimate_css', 'enable' );
	update_option( 'ultimate_js', 'enable' );

}