<?php
/*
 * Add-on Name: Advanced Single Image Module
 */

if ( ! class_exists( 'St_Advanced_Single_Image_Module' ) ) {
	class St_Advanced_Single_Image_Module {
		function __construct() {
			add_shortcode( 'st_advanced_single_image_module', array( $this, 'advanced_single_image_module_shortcode' ) );
			add_action( 'init', array( $this, 'advanced_single_image_module_init' ) );
		}

		function advanced_single_image_module_shortcode( $atts ) {
			$el_class = $module_animation = $animation = $animated = $hover_title = '';

			extract( shortcode_atts( array(
				'image'               => '',
				'image_width'         => '',
				'image_height'        => '',
				'image_align'         => '',
				'onclick'             => '',
				'custom_link'         => '',
				'overlay_type'        => '',
				'overlay_hover'       => '',
				'overlay_color'       => '',
				'overlay_color_hover' => '',
				'hover_title'         => '',
				'module_animation'    => '',
				'el_class'            => '',
			), $atts ) );

			$output = '';

			// Animation
			if ( $module_animation ) {
				$animated  .= ' st-animation';
				$animation .= 'data-animation="' . esc_attr( $module_animation ) . '"';
			}

			$id = uniqid( 'st-advanced-single-image-' );

			$advanced_image = '';
			$link_start     = '';
			$link_end       = '';

			$img = wp_get_attachment_image_src( $image, 'full' );

			$align = '';

			if ( empty( $image_align ) ) {
				$align .= '';
			}

			if ( $image_align == 'center' ) {
				$align .= 'center';
			}

			if ( empty( $overlay_type ) ) {
				$overlay_type = 'none';
			}

			if ( empty( $overlay_hover ) ) {
				$overlay_hover = 'zoom';
			}

			if ( $image_align == 'right' ) {
				$align .= 'right';
			}

			if ( ! empty( $overlay_color ) ) {
				$overlay_style = 'style="background-color:' . $overlay_color . ';"';
			} else {
				$overlay_style = '';
			}

			if ( ! empty( $overlay_color_hover ) ) {
				$overlay_hover_style = '<style type="text/css">#' . esc_attr( $id ) . ':hover .st-advanced-image-overlay{background-color:' . $overlay_color_hover . ' !important;}</style>';
			} else {
				$overlay_hover_style = '';
			}

			$style = 'style="';
			$style .= 'background-image:url(' . esc_url( $img[0] ) . ');';
			if ( ! empty( $image_height ) ) {
				$style .= 'height:' . esc_attr( $image_height ) . ';';
			} else {
				$style .= 'height:100%;';
			}
			if ( ! empty( $image_width ) ) {
				$style .= 'width:' . esc_attr( $image_width ) . ';';
			} else {
				$style .= 'width:100%;';
			}
			$style .= '"';

			$overlay = '';
			if ( $overlay_type == 'main_color' ) {
				$el_class .= ' overlay';
			}

			$image_wrap_start = '<div class="st-advanced-image ' . esc_attr( $el_class ) . '" id="' . esc_attr( $id ) . '">';
			$image_wrap_end   = '</div>';

			if ( $onclick == 'link_image' || $onclick == 'img_link_large' || $onclick == 'custom_link' ) {
				if ( $overlay_hover == 'zoom' ) {
					$overlay .= '<div class="st-advanced-image-overlay" ' . $overlay_style . '><div class="overlay-inner-icon"></div><div class="overlay-inner-left"></div><div class="overlay-inner-right"></div></div>';
				}
				if ( $overlay_hover == 'title' ) {
					$overlay .= '<div class="st-advanced-image-overlay" ' . $overlay_style . '><div class="st-advanced-image-overlay-title">' . $hover_title . '<i class="st-h-after"><i></i><i><i></i></i></i></div></div>';
				}
			}

			$pretty_rel_random = ' data-rel="prettyPhoto[rel-' . get_the_ID() . '-' . rand() . ']"';

			$img_div = '<div class="st-advanced-image-inner ' . esc_attr( $align ) . '" ' . $style . '></div>';

			$link_start = $link_end = '';

			if ( $onclick == 'link_image' ) {
				$link_start = '<a rel="prettyPhoto[slides]" href="' . esc_url( $img[0] ) . '"' . $pretty_rel_random . '>';
				$link_end   = '</a>';
			}

			if ( $onclick == 'img_link_large' ) {
				$link_start = '<a href="' . esc_url( $img[0] ) . '">';
				$link_end   = '</a>';
			}

			if ( $onclick == 'custom_link' ) {
				$link_start = '<a class="custom-link" href="' . esc_url( $custom_link ) . '">';
				$link_end   = '</a>';
			}

			$advanced_image .= $link_start . $overlay . $img_div . $link_end;

			$output .= $image_wrap_start . $advanced_image . $image_wrap_end;

			if ( $overlay_hover_style != '' ) {
				$output .= "<script type=\"text/javascript\">jQuery(document).ready(function(){jQuery('head').append('" . $overlay_hover_style . "');});</script>";
			}

			return $output;
		}

		function advanced_single_image_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Advanced Single Image', 'adamas-vc-shortcodes' ),
					'base'        => 'st_advanced_single_image_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/advanced_single_image.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Single image with settings', 'adamas-vc-shortcodes' ), // TODO : Add description
					'params'      => array(
						array(
							'type'        => 'attach_image',
							'heading'     => __( 'Image', 'adamas-vc-shortcodes' ),
							'param_name'  => 'image',
							'description' => '',
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Image width', 'adamas-vc-shortcodes' ),
							'param_name'  => 'image_width',
							'description' => __( 'Enter image width using CSS values (in px, %, etc).', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Image height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'image_height',
							'description' => __( 'Enter image height using CSS values (in px, %, etc).', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'Image alignment', 'adamas-vc-shortcodes' ),
							'param_name'  => 'image_align',
							'value'       => array(
								__( 'Left', 'adamas-vc-shortcodes' )   => 'left',
								__( 'Right', 'adamas-vc-shortcodes' )  => 'right',
								__( 'Center', 'adamas-vc-shortcodes' ) => 'center',
							),
							'description' => __( 'Select image alignment.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'On click action', 'adamas-vc-shortcodes' ),
							'param_name'  => 'onclick',
							'value'       => array(
								__( 'None', 'adamas-vc-shortcodes' )                => '',
								__( 'Link to large image', 'adamas-vc-shortcodes' ) => 'img_link_large',
								__( 'Open prettyPhoto', 'adamas-vc-shortcodes' )    => 'link_image',
								__( 'Open custom link', 'adamas-vc-shortcodes' )    => 'custom_link',
							),
							'description' => __( 'Select action for click action.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'       => 'dropdown',
							'heading'    => __( 'Overlay type', 'adamas-vc-shortcodes' ),
							'param_name' => 'overlay_type',
							'value'      => array(
								__( 'None', 'adamas-vc-shortcodes' )                     => 'none',
								__( 'Main theme color overlay', 'adamas-vc-shortcodes' ) => 'main_color',
							),
						),
						array(
							'type'       => 'dropdown',
							'heading'    => __( 'Display on hover', 'adamas-vc-shortcodes' ),
							'param_name' => 'overlay_hover',
							'value'      => array(
								__( 'Zoom icon', 'adamas-vc-shortcodes' ) => 'zoom',
								__( 'Title', 'adamas-vc-shortcodes' )     => 'title',
							),
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Overlay color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'overlay_color',
							'description' => __( 'Please, select color for overlay.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Overlay color on hover', 'adamas-vc-shortcodes' ),
							'param_name'  => 'overlay_color_hover',
							'description' => __( 'Please, select color for overlay on hover.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'       => 'textfield',
							'heading'    => __( 'Title on hover', 'adamas-vc-shortcodes' ),
							'param_name' => 'hover_title',
							'dependency' => Array( 'element' => 'overlay_hover', 'value' => array( 'title' ) ),
						),
						array(
							'type'       => 'textfield',
							'heading'    => __( 'Custom image link', 'adamas-vc-shortcodes' ),
							'param_name' => 'custom_link',
							'dependency' => Array( 'element' => 'onclick', 'value' => array( 'custom_link' ) ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_advanced_single_image_module = new St_Advanced_Single_Image_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_advanced_single_image_module extends WPBakeryShortCode {
		}
	}
}