<?php
/*
 * Theme custom VC Settings
 */

// New VC shortcodes directory path
if ( function_exists( 'vc_set_shortcodes_templates_dir' ) ) {
	$vc_templates_dir = plugin_dir_path( __FILE__ ) . '/vc_templates/';
	vc_set_shortcodes_templates_dir( $vc_templates_dir );
}

// Animations array
if ( ! function_exists( 'st_adamas_animations_list' ) ) {
	function st_adamas_animations_list() {
		return array(
			esc_html__( 'Without animation', 'adamas-vc-shortcodes' )           => '',
			esc_html__( 'Fade In', 'adamas-vc-shortcodes' )                     => 'transition.fadeIn',
			esc_html__( 'Flip In Horizontally', 'adamas-vc-shortcodes' )        => 'transition.flipXIn',
			esc_html__( 'Flip In Vertically', 'adamas-vc-shortcodes' )          => 'transition.flipYIn',
			esc_html__( 'Flip Bounce In Horizontally', 'adamas-vc-shortcodes' ) => 'transition.flipBounceXIn',
			esc_html__( 'Flip Bounce In Vertically', 'adamas-vc-shortcodes' )   => 'transition.flipBounceYIn',
			esc_html__( 'Swoop In', 'adamas-vc-shortcodes' )                    => 'transition.swoopIn',
			esc_html__( 'Whirl In', 'adamas-vc-shortcodes' )                    => 'transition.whirlIn',
			esc_html__( 'Shrink In', 'adamas-vc-shortcodes' )                   => 'transition.shrinkIn',
			esc_html__( 'Expand In', 'adamas-vc-shortcodes' )                   => 'transition.expandIn',
			esc_html__( 'Bounce In', 'adamas-vc-shortcodes' )                   => 'transition.bounceIn',
			esc_html__( 'Bounce Up In', 'adamas-vc-shortcodes' )                => 'transition.bounceUpIn',
			esc_html__( 'Bounce Down In', 'adamas-vc-shortcodes' )              => 'transition.bounceDownIn',
			esc_html__( 'Bounce Left In', 'adamas-vc-shortcodes' )              => 'transition.bounceLeftIn',
			esc_html__( 'Bounce Right In', 'adamas-vc-shortcodes' )             => 'transition.bounceRightIn',
			esc_html__( 'Slide Up In', 'adamas-vc-shortcodes' )                 => 'transition.slideUpIn',
			esc_html__( 'Slide Down In', 'adamas-vc-shortcodes' )               => 'transition.slideDownIn',
			esc_html__( 'Slide Left In', 'adamas-vc-shortcodes' )               => 'transition.slideLeftIn',
			esc_html__( 'Slide Right In', 'adamas-vc-shortcodes' )              => 'transition.slideRightIn',
			esc_html__( 'Slide Up Big In', 'adamas-vc-shortcodes' )             => 'transition.slideUpBigIn',
			esc_html__( 'Slide Down Big In', 'adamas-vc-shortcodes' )           => 'transition.slideDownBigIn',
			esc_html__( 'Slide Left Big In', 'adamas-vc-shortcodes' )           => 'transition.slideLeftBigIn',
			esc_html__( 'Slide Right Big In', 'adamas-vc-shortcodes' )          => 'transition.slideRightBigIn',
			esc_html__( 'Perspective Up In', 'adamas-vc-shortcodes' )           => 'transition.perspectiveUpIn',
			esc_html__( 'Perspective Down In', 'adamas-vc-shortcodes' )         => 'transition.perspectiveDownIn',
			esc_html__( 'Perspective Left In', 'adamas-vc-shortcodes' )         => 'transition.perspectiveLeftIn',
			esc_html__( 'Perspective Right In', 'adamas-vc-shortcodes' )        => 'transition.perspectiveRightIn',
		);
	}
}

// Single page select
if ( ! function_exists( 'st_adamas_single_page_select' ) ) {
	function st_adamas_single_page_select() {
		$args        = array(
			'post_type'      => 'page',
			'post_status'    => 'publish',
			'posts_per_page' => - 1,
		);
		$pages_query = new WP_Query( $args );
		$pages       = array();
		if ( $pages_query !== null ) {
			foreach ( $pages_query->posts as $page ) {
				$page_title           = get_the_title( $page->ID );
				$pages[ $page_title ] = $page->ID;
			}
		}

		return $pages;
	}
}

// Taxonomy select
if ( ! function_exists( 'st_adamas_taxonomy_select' ) ) {
	function st_adamas_taxonomy_select( $cat = '' ) {
		$args = array(
			'taxonomy'   => $cat,
			'hide_empty' => false,
		);

		$terms = get_terms( $args );
		$arr   = array();

		if ( ! empty( $terms ) ) {
			foreach ( $terms as $term ) {
				$arr[ $term->name ] = $term->slug;
			}
		}

		return $arr;
	}
}

// Projects select
if ( ! function_exists( 'st_adamas_projects_select' ) ) {
	function st_adamas_projects_select() {
		$args           = array(
			'post_type'      => 'projects',
			'post_status'    => 'publish',
			'posts_per_page' => - 1,
		);
		$projects_query = new WP_Query( $args );
		$projects       = array();
		if ( $projects_query !== null ) {
			foreach ( $projects_query->posts as $project ) {
				$project_title              = get_the_title( $project->ID );
				$projects[ $project_title ] = $project->ID;
			}
		}

		return $projects;
	}
}

// Testimonials select
if ( ! function_exists( 'st_adamas_testimonials_select' ) ) {
	function st_adamas_testimonials_select() {
		$args               = array(
			'post_type'      => 'testimonials',
			'post_status'    => 'publish',
			'posts_per_page' => - 1,
		);
		$testimonials_query = new WP_Query( $args );
		$testimonials       = array();
		if ( $testimonials_query !== null ) {
			foreach ( $testimonials_query->posts as $testimonial ) {
				$testimonial_title                  = get_the_title( $testimonial->ID );
				$testimonials[ $testimonial_title ] = $testimonial->ID;
			}
		}

		return $testimonials;
	}
}

// Additional VC modules settings
if ( function_exists( 'vc_add_param' ) ) {
	vc_add_param( 'vc_row', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Content Width', 'adamas-vc-shortcodes' ),
		'param_name'  => 'st_row_width',
		'weight'      => 10,
		'value'       => array(
			esc_html__( 'Default', 'adamas-vc-shortcodes' )    => 'row',
			esc_html__( 'Full width', 'adamas-vc-shortcodes' ) => 'row-full-width',
		),
		'description' => esc_html__( 'Select row width (Default: 1200px; Full width: screen width;)', 'adamas-vc-shortcodes' ),
	) );

	// Animations params
	vc_add_param( 'vc_column_text', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
		'param_name'  => 'module_animation',
		'value'       => st_adamas_animations_list(),
		'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
	) );
	vc_add_param( 'vc_single_image', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
		'param_name'  => 'module_animation',
		'value'       => st_adamas_animations_list(),
		'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
	) );
	vc_add_param( 'vc_custom_heading', array(
			'type'        => 'dropdown',
			'class'       => '',
			'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
			'param_name'  => 'module_animation',
			'value'       => st_adamas_animations_list(),
			'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
		)
	);
	vc_add_param( 'st_activity_grid_item', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
		'param_name'  => 'module_animation',
		'value'       => st_adamas_animations_list(),
		'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
	) );
	vc_add_param( 'st_main_products_item', array(
			'type'        => 'dropdown',
			'class'       => '',
			'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
			'param_name'  => 'module_animation',
			'value'       => st_adamas_animations_list(),
			'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
		)
	);
	vc_add_param( 'st_posts_module', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
		'param_name'  => 'module_animation',
		'value'       => st_adamas_animations_list(),
		'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
	) );
	vc_add_param( 'st_process_module', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
		'param_name'  => 'module_animation',
		'value'       => st_adamas_animations_list(),
		'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
	) );
	vc_add_param( 'st_process_module_b', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
		'param_name'  => 'module_animation',
		'value'       => st_adamas_animations_list(),
		'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
	) );
	vc_add_param( 'st_product_info', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
		'param_name'  => 'module_animation',
		'value'       => st_adamas_animations_list(),
		'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
	) );
	vc_add_param( 'st_simple_link', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
		'param_name'  => 'module_animation',
		'value'       => st_adamas_animations_list(),
		'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
	) );

	// Responsive options params for columns
	vc_add_param( 'vc_column', array(
		'type'        => 'checkbox',
		'class'       => '',
		'heading'     => esc_html__( 'Remove paddings and margins on mobile', 'adamas-vc-shortcodes' ),
		'param_name'  => 'st_column_responsive_remove_css',
		'value'       => array(
			esc_html__( 'Remove all paddings', 'adamas-vc-shortcodes' ) => 'st-remove-paddings',
			esc_html__( 'Remove all margins', 'adamas-vc-shortcodes' )  => 'st-remove-margins',
			esc_html__( 'Remove all borders', 'adamas-vc-shortcodes' )  => 'st-remove-borders',
		),
		'description' => esc_html__( 'Check to remove paddings or margins on mobile.', 'adamas-vc-shortcodes' ),
		'group'       => esc_html__( 'Responsive Options', 'adamas-vc-shortcodes' ),
	) );

	vc_add_param( 'vc_column_inner', array(
		'type'        => 'checkbox',
		'class'       => '',
		'heading'     => esc_html__( 'Remove paddings, margins, borders on mobile', 'adamas-vc-shortcodes' ),
		'param_name'  => 'st_column_inner_responsive_remove_css',
		'value'       => array(
			esc_html__( 'Remove all paddings', 'adamas-vc-shortcodes' ) => 'st-remove-paddings',
			esc_html__( 'Remove all margins', 'adamas-vc-shortcodes' )  => 'st-remove-margins',
			esc_html__( 'Remove all borders', 'adamas-vc-shortcodes' )  => 'st-remove-borders',
		),
		'description' => esc_html__( 'Check to remove paddings or margins on mobile (>1199px).', 'adamas-vc-shortcodes' ),
		'group'       => esc_html__( 'Responsive Options', 'adamas-vc-shortcodes' ),
	) );

	// Heading before/after element
	vc_add_param( 'vc_custom_heading', array(
		'type'        => 'checkbox',
		'class'       => '',
		'heading'     => esc_html__( 'Enable heading elements', 'adamas-vc-shortcodes' ),
		'param_name'  => 'custom_heading_enable_elem',
		'description' => esc_html__( 'Check this if you want to enable elements before or after heading.', 'adamas-vc-shortcodes' ),
		'value'       => array( esc_html__( 'Yes', 'adamas-vc-shortcodes' ) => 'yes' ),
	) );

	// Heading before/after element background check
	vc_add_param( 'vc_custom_heading', array(
		'type'        => 'checkbox',
		'class'       => '',
		'heading'     => esc_html__( 'Heading-element background check', 'adamas-vc-shortcodes' ),
		'param_name'  => 'custom_heading_elem_bg_check',
		'description' => esc_html__( 'Check this if this heading placed on colored or dark background.', 'adamas-vc-shortcodes' ),
		'value'       => array( esc_html__( 'Yes', 'adamas-vc-shortcodes' ) => 'yes' ),
		'dependency'  => Array( 'element' => 'custom_heading_enable_elem', 'value' => 'yes' ),
	) );

	// Element type
	vc_add_param( 'vc_custom_heading', array(
		"type"       => "dropdown",
		"heading"    => esc_html__( "Heading element type", "adamas-vc-shortcodes" ),
		"param_name" => "elem_type",
		"value"      => array(
			esc_html__( "Line gradient", "adamas-vc-shortcodes" )                  => "gradient",
			esc_html__( "Side line", "adamas-vc-shortcodes" )                      => "side",
			esc_html__( "Top line", "adamas-vc-shortcodes" )                       => "top",
			esc_html__( "Bottom line", "adamas-vc-shortcodes" )                    => "bottom",
			esc_html__( "Square", "adamas-vc-shortcodes" )                         => "square_3",
			esc_html__( "Square with empty space inside", "adamas-vc-shortcodes" ) => "square_2",
			esc_html__( "Square with line", "adamas-vc-shortcodes" )               => "square",
			esc_html__( "Circle", "adamas-vc-shortcodes" )                         => "circle",
			esc_html__( "Ring", "adamas-vc-shortcodes" )                           => "ring",
		),
		"dependency" => Array( "element" => "custom_heading_enable_elem", "value" => "yes" ),
	) );

	// Top element height
	vc_add_param( 'vc_custom_heading', array(
		"type"        => "textfield",
		"heading"     => esc_html__( "Top element height", "adamas-vc-shortcodes" ),
		"param_name"  => "elem_top_height",
		"description" => esc_html__( "Set top element height (in px).", "adamas-vc-shortcodes" ),
		"dependency"  => Array( "element" => "elem_type", "value" => "top" ),
	) );

	// Bottom element height
	vc_add_param( 'vc_custom_heading', array(
		"type"        => "textfield",
		"heading"     => esc_html__( "Bottom element height", "adamas-vc-shortcodes" ),
		"param_name"  => "elem_bottom_height",
		"description" => esc_html__( "Set bottom element height (in px).", "adamas-vc-shortcodes" ),
		"dependency"  => Array( "element" => "elem_type", "value" => "bottom" ),
	) );

	// Element color
	vc_add_param( 'vc_custom_heading', array(
		'type'       => 'colorpicker',
		'heading'    => esc_html__( 'Before/after heading element color', 'adamas-vc-shortcodes' ),
		'param_name' => 'heading_elem_color',
		"dependency" => Array( "element" => "custom_heading_enable_elem", "value" => "yes" ),
	) );

	// Background text effect
	vc_add_param( 'vc_custom_heading', array(
		'type'        => 'checkbox',
		'class'       => '',
		'heading'     => esc_html__( 'Enable background-text effect', 'adamas-vc-shortcodes' ),
		'param_name'  => 'custom_heading_enable_bg_text',
		'value'       => array( esc_html__( 'Yes', 'adamas-vc-shortcodes' ) => 'yes' ),
		'description' => esc_html__( 'Check this if you want to enable heading background-text effect.', 'adamas-vc-shortcodes' ),
	) );

	// Color for background text effect
	vc_add_param( 'vc_custom_heading', array(
		'type'        => 'colorpicker',
		'class'       => '',
		'heading'     => esc_html__( 'Heading background-text color', 'adamas-vc-shortcodes' ),
		'param_name'  => 'custom_heading_bg_text_color',
		'description' => esc_html__( 'Choose color for heading background text.', 'adamas-vc-shortcodes' ),
		'value'       => '',
		'dependency'  => Array( 'element' => 'custom_heading_enable_bg_text', 'value' => 'yes' ),
	) );

	vc_add_param( 'vc_custom_heading', array(
		'type'        => 'number',
		'class'       => '',
		'heading'     => esc_html__( 'Heading background-text font size', 'adamas-vc-shortcodes' ),
		'param_name'  => 'custom_heading_bg_text_font_size',
		'description' => esc_html__( 'Set font size for heading background-text in px. Default is 90px.', 'adamas-vc-shortcodes' ),
		'value'       => '',
		'suffix'      => 'px',
		'dependency'  => Array( 'element' => 'custom_heading_enable_bg_text', 'value' => 'yes' ),
	) );

	vc_add_param( 'vc_custom_heading', array(
		'type'        => 'number',
		'class'       => '',
		'heading'     => esc_html__( 'Heading background-text vertical position', 'adamas-vc-shortcodes' ),
		'param_name'  => 'custom_heading_bg_text_vposition',
		'description' => esc_html__( 'Set vertical position for heading background-text in px. Default is -65px.', 'adamas-vc-shortcodes' ),
		'value'       => '',
		'suffix'      => 'px',
		'dependency'  => Array( 'element' => 'custom_heading_enable_bg_text', 'value' => 'yes' ),
	) );

	vc_add_param( 'vc_custom_heading', array(
		'type'        => 'number',
		'class'       => '',
		'heading'     => esc_html__( 'Heading background-text horizontal position', 'adamas-vc-shortcodes' ),
		'param_name'  => 'custom_heading_bg_text_hposition',
		'description' => esc_html__( 'Set horizontal position for heading background-text in %. Default is 30%.', 'adamas-vc-shortcodes' ),
		'value'       => '',
		'suffix'      => '%',
		'dependency'  => Array( 'element' => 'custom_heading_enable_bg_text', 'value' => 'yes' ),
	) );

	// Legend position for round and line charts
	vc_add_param( 'vc_round_chart', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Legend position', 'adamas-vc-shortcodes' ),
		'param_name'  => 'legend_position',
		'description' => esc_html__( 'Choose legend position.', 'adamas-vc-shortcodes' ),
		'value'       => array(
			esc_html__( 'Default (right)', 'adamas-vc-shortcodes' )      => '',
			esc_html__( 'Bottom (under chart)', 'adamas-vc-shortcodes' ) => 'st-legend-bottom',
		),
		'dependency'  => Array( 'element' => 'legend', 'value' => 'yes' ),
	) );

	vc_add_param( 'vc_line_chart', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Legend position', 'adamas-vc-shortcodes' ),
		'param_name'  => 'legend_position',
		'description' => esc_html__( 'Choose legend position.', 'adamas-vc-shortcodes' ),
		'value'       => array(
			esc_html__( 'Default (right)', 'adamas-vc-shortcodes' )      => '',
			esc_html__( 'Bottom (under chart)', 'adamas-vc-shortcodes' ) => 'st-legend-bottom',
		),
		'dependency'  => Array( 'element' => 'legend', 'value' => 'yes' ),
	) );

	// Background for TTA Section
	vc_add_param( 'vc_tta_section', array(
		'type'        => 'attach_image',
		'class'       => '',
		'heading'     => esc_html__( 'Background image', 'adamas-vc-shortcodes' ),
		'param_name'  => 'section_bg',
		'value'       => '',
		'description' => esc_html__( 'Set background image for section.', 'adamas-vc-shortcodes' ),
	) );

	// Left/Right for Widgetized Sidebar
	vc_add_param( 'vc_widget_sidebar', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Sidebar position', 'adamas-vc-shortcodes' ),
		'param_name'  => 'sidebar_position',
		'value'       => array(
			esc_html__( 'Left', 'adamas-vc-shortcodes' )  => 'left',
			esc_html__( 'Right', 'adamas-vc-shortcodes' ) => 'right',
		),
		'description' => esc_html__( 'Select position of this sidebar.', 'adamas-vc-shortcodes' ),
	) );

	// Left/Right Align for Progress Bar
	vc_add_param( 'vc_progress_bar', array(
		'type'        => 'dropdown',
		'class'       => '',
		'heading'     => esc_html__( 'Progress bar alignment', 'adamas-vc-shortcodes' ),
		'param_name'  => 'progress_bar_alignment',
		'value'       => array(
			esc_html__( 'Left', 'adamas-vc-shortcodes' )  => 'left',
			esc_html__( 'Right', 'adamas-vc-shortcodes' ) => 'right',
		),
		'description' => esc_html__( 'Select progress bar text alignment.', 'adamas-vc-shortcodes' ),
	) );

	// Colorpicker for bar background for Progress Bar
	vc_add_param( 'vc_progress_bar', array(
		'type'        => 'colorpicker',
		'class'       => '',
		'heading'     => esc_html__( 'Custom background color for bars', 'adamas-vc-shortcodes' ),
		'param_name'  => 'progress_bar_bg_color',
		'description' => esc_html__( 'Select custom background color for bars (lighter section)', 'adamas-vc-shortcodes' ),
	) );

	// Pie Chart params
	vc_add_param( 'vc_pie', array(
		'type'        => 'textfield',
		'class'       => '',
		'heading'     => esc_html__( 'Bar width', 'adamas-vc-shortcodes' ),
		'param_name'  => 'pie_bar_width',
		'description' => esc_html__( 'Set bar width in px.', 'adamas-vc-shortcodes' ),
	) );
	vc_add_param( 'vc_pie', array(
		'type'       => 'colorpicker',
		'class'      => '',
		'heading'    => esc_html__( 'Bar Background Color', 'adamas-vc-shortcodes' ),
		'param_name' => 'pie_bar_bg_color',
	) );
	vc_add_param( 'vc_pie', array(
		'type'       => 'colorpicker',
		'class'      => '',
		'heading'    => esc_html__( 'Bar Value Color', 'adamas-vc-shortcodes' ),
		'param_name' => 'pie_bar_value_color',
	) );
	vc_add_param( 'vc_pie', array(
		'type'       => 'colorpicker',
		'class'      => '',
		'heading'    => esc_html__( 'Chart Background Color', 'adamas-vc-shortcodes' ),
		'param_name' => 'pie_chart_bg_color',
	) );
	vc_add_param( 'vc_pie', array(
		'type'        => 'ultimate_google_fonts',
		'heading'     => esc_html__( 'Value font family', 'adamas-vc-shortcodes' ),
		'param_name'  => 'value_font',
		'value'       => '',
		'description' => '',
		'group'       => 'Typography',
	) );
	vc_add_param( 'vc_pie', array(
		'type'        => 'ultimate_google_fonts_style',
		'heading'     => esc_html__( 'Value style', 'adamas-vc-shortcodes' ),
		'param_name'  => 'value_font_style',
		'value'       => '',
		'description' => '',
		'group'       => 'Typography',
	) );
	vc_add_param( 'vc_pie', array(
		'type'        => 'colorpicker',
		'heading'     => esc_html__( 'Value color', 'adamas-vc-shortcodes' ),
		'param_name'  => 'value_color',
		'value'       => '',
		'description' => '',
		'group'       => 'Typography',
	) );
	vc_add_param( 'vc_pie', array(
		'type'       => 'ultimate_responsive',
		'class'      => '',
		'heading'    => esc_html__( 'Value font size', 'adamas-vc-shortcodes' ),
		'param_name' => 'value_font_size',
		'unit'       => 'px',
		'media'      => array(
			"Desktop"          => '',
			"Tablet"           => '',
			"Tablet Portrait"  => '',
			"Mobile Landscape" => '',
			"Mobile"           => '',
		),
		'group'      => 'Typography',
	) );
	vc_add_param( 'vc_pie', array(
		'type'        => 'number',
		'heading'     => esc_html__( 'Value letter spacing', 'adamas-vc-shortcodes' ),
		'param_name'  => 'value_letter_spacing',
		'value'       => '',
		'description' => '',
		'suffix'      => 'px',
		'group'       => 'Typography',
	) );
}

// CTA button vertical align if no content (Middle param to Add button)
add_action( 'vc_after_init', 'st_adamas_cta_button_mid' );
function st_adamas_cta_button_mid() {
	$param                                                            = WPBMap::getParam( 'vc_cta', 'add_button' );
	$param['value'][ esc_html__( 'Middle', 'adamas-vc-shortcodes' ) ] = 'middle';
	vc_update_shortcode_param( 'vc_cta', $param );
}

// VC Tour theme style
add_action( 'vc_after_init', 'st_adamas_tta_tour_style' );
function st_adamas_tta_tour_style() {
	$param                                                                 = WPBMap::getParam( 'vc_tta_tour', 'style' );
	$param['value'][ esc_html__( 'Theme style', 'adamas-vc-shortcodes' ) ] = 'adamas-vc-shortcodes';
	vc_update_shortcode_param( 'vc_tta_tour', $param );
}

// VC Accordion theme style
add_action( 'vc_after_init', 'st_adamas_tta_accordion_style' );
function st_adamas_tta_accordion_style() {
	$param                                                                 = WPBMap::getParam( 'vc_tta_accordion', 'style' );
	$param['value'][ esc_html__( 'Theme style', 'adamas-vc-shortcodes' ) ] = 'adamas-vc-shortcodes';
	vc_update_shortcode_param( 'vc_tta_accordion', $param );
}

// Line Chart Radar
add_action( 'vc_after_init', 'st_adamas_line_chart_radar' );
function st_adamas_line_chart_radar() {
	$param                                                           = WPBMap::getParam( 'vc_line_chart', 'type' );
	$param['value'][ esc_html__( 'Radar', 'adamas-vc-shortcodes' ) ] = 'radar';
	vc_update_shortcode_param( 'vc_line_chart', $param );
}

// Round Chart Polar
add_action( 'vc_after_init', 'st_adamas_round_chart_polar' );
function st_adamas_round_chart_polar() {
	$param                                                                = WPBMap::getParam( 'vc_round_chart', 'type' );
	$param['value'][ esc_html__( 'Polar Area', 'adamas-vc-shortcodes' ) ] = 'polarArea';
	vc_update_shortcode_param( 'vc_round_chart', $param );
}

// Progress Bar
add_action( 'vc_after_init', 'st_adamas_progress_bar' );
function st_adamas_progress_bar() {
	$param           = WPBMap::getParam( 'vc_progress_bar', 'values' );
	$param['params'] = array(
		array(
			'type'        => 'textfield',
			'heading'     => __( 'Label', 'adamas-vc-shortcodes' ),
			'param_name'  => 'label',
			'description' => __( 'Enter text used as title of bar.', 'adamas-vc-shortcodes' ),
			'admin_label' => true,
		),
		array(
			'type'        => 'textfield',
			'heading'     => __( 'Value', 'adamas-vc-shortcodes' ),
			'param_name'  => 'value',
			'description' => __( 'Enter value of bar.', 'adamas-vc-shortcodes' ),
			'admin_label' => true,
		),
		array(
			'type'        => 'textfield',
			'heading'     => __( 'Max value', 'adamas-vc-shortcodes' ),
			'param_name'  => 'max_value',
			'description' => __( 'Enter max value of bar.', 'adamas-vc-shortcodes' ),
		),
		array(
			'type'               => 'dropdown',
			'heading'            => __( 'Color', 'adamas-vc-shortcodes' ),
			'param_name'         => 'color',
			'value'              => array(
				                        __( 'Default', 'adamas-vc-shortcodes' ) => '',
			                        ) + array(
				                        __( 'Classic Grey', 'adamas-vc-shortcodes' )      => 'bar_grey',
				                        __( 'Classic Blue', 'adamas-vc-shortcodes' )      => 'bar_blue',
				                        __( 'Classic Turquoise', 'adamas-vc-shortcodes' ) => 'bar_turquoise',
				                        __( 'Classic Green', 'adamas-vc-shortcodes' )     => 'bar_green',
				                        __( 'Classic Orange', 'adamas-vc-shortcodes' )    => 'bar_orange',
				                        __( 'Classic Red', 'adamas-vc-shortcodes' )       => 'bar_red',
				                        __( 'Classic Black', 'adamas-vc-shortcodes' )     => 'bar_black',
			                        ) + vc_get_shared( 'colors-dashed' ) + array(
				                        __( 'Custom Color', 'adamas-vc-shortcodes' ) => 'custom',
			                        ),
			'description'        => __( 'Select single bar background color.', 'adamas-vc-shortcodes' ),
			'admin_label'        => true,
			'param_holder_class' => 'vc_colored-dropdown',
		),
		array(
			'type'        => 'colorpicker',
			'heading'     => __( 'Custom color', 'adamas-vc-shortcodes' ),
			'param_name'  => 'customcolor',
			'description' => __( 'Select custom single bar background color.', 'adamas-vc-shortcodes' ),
			'dependency'  => array(
				'element' => 'color',
				'value'   => array( 'custom' ),
			),
		),
		array(
			'type'        => 'colorpicker',
			'heading'     => __( 'Custom text color', 'adamas-vc-shortcodes' ),
			'param_name'  => 'customtxtcolor',
			'description' => __( 'Select custom single bar text color.', 'adamas-vc-shortcodes' ),
			'dependency'  => array(
				'element' => 'color',
				'value'   => array( 'custom' ),
			),
		),
	);
	vc_update_shortcode_param( 'vc_progress_bar', $param );
}

// Removing params
if ( function_exists( 'vc_remove_param' ) ) {
	vc_remove_param( 'vc_row', 'full_width' );
	vc_remove_param( 'vc_column_text', 'css_animation' );
	vc_remove_param( 'vc_single_image', 'css_animation' );
	vc_remove_param( 'vc_tta_tour', 'color' );
	vc_remove_param( 'vc_tta_accordion', 'color' );
	vc_remove_param( 'vc_pie', 'color' );
	vc_remove_param( 'vc_pie', 'custom_color' );
	vc_remove_param( 'vc_line_chart', 'title' );
	vc_remove_param( 'vc_round_chart', 'title' );
}

// Removing modules
if ( function_exists( 'vc_remove_element' ) ) {
	vc_remove_element( 'vc_tabs' );
}

// Custom VC modules
if ( function_exists( 'vc_map' ) ) {

	// Activity Grid Container
	class WPBakeryShortCode_St_Activity_Grid extends WPBakeryShortCodesContainer {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Activity Grid', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_activity_grid',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/activity_grid.png',
		'as_parent'               => array( 'only' => 'st_activity_grid_item' ),
		'content_element'         => true,
		'show_settings_on_create' => false,
		'js_view'                 => 'VcColumnView',
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Activity Grid Item
	class WPBakeryShortCode_St_Activity_Grid_Item extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Activity Grid Item', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_activity_grid_item',
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/activity_grid.png',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'as_child'                => array( 'only' => 'st_activity_grid' ),
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Section title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'activity_title',
				'description' => esc_html__( 'Enter section title for an element.', 'adamas-vc-shortcodes' ),
				'admin_label' => true,
			),
			array(
				'type'        => 'textarea_html',
				'heading'     => esc_html__( 'Section description', 'adamas-vc-shortcodes' ),
				'param_name'  => 'content',
				'description' => esc_html__( 'Enter description for this section.', 'adamas-vc-shortcodes' )
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'Section link', 'adamas-vc-shortcodes' ),
				'param_name'  => 'activity_link',
				'description' => esc_html__( 'Enter link for this section.', 'adamas-vc-shortcodes' )
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Section image', 'adamas-vc-shortcodes' ),
				'param_name'  => 'activity_img',
				'description' => esc_html__( 'Choose image for section.', 'adamas-vc-shortcodes' )
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// History Item
	class WPBakeryShortCode_St_History_Item extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'History Item', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_history_item',
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/history_item.png',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Layout', 'adamas-vc-shortcodes' ),
				'param_name'  => 'history_layout',
				'value'       => array(
					esc_html__( 'Image and year left - Title and description right', 'adamas-vc-shortcodes' ) => 'history-year-title',
					esc_html__( 'Title and description left - Image and year right', 'adamas-vc-shortcodes' ) => 'history-title-year',
				),
				'description' => esc_html__( 'Set layout of history block.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Year', 'adamas-vc-shortcodes' ),
				'param_name'  => 'history_year',
				'description' => ''
			),
			array(
				'type'        => 'colorpicker',
				'heading'     => esc_html__( 'Year color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'year_color',
				'description' => ''
			),
			array(
				'type'        => 'colorpicker',
				'heading'     => esc_html__( 'Background color for year block', 'adamas-vc-shortcodes' ),
				'param_name'  => 'year_bg_color',
				'description' => esc_html__( 'Set background color for year block.', 'adamas-vc-shortcodes' )
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'history_title',
				'description' => esc_html__( 'Enter section title for this section.', 'adamas-vc-shortcodes' ),
				'admin_label' => true
			),
			array(
				'type'        => 'textarea_html',
				'heading'     => esc_html__( 'Description', 'adamas-vc-shortcodes' ),
				'param_name'  => 'content',
				'description' => esc_html__( 'Enter description for this section.', 'adamas-vc-shortcodes' )
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Image', 'adamas-vc-shortcodes' ),
				'param_name'  => 'history_img',
				'description' => esc_html__( 'Choose image for this section.', 'adamas-vc-shortcodes' )
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'Link', 'adamas-vc-shortcodes' ),
				'param_name'  => 'history_link',
				'description' => esc_html__( 'Set link for this section.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Posts Module
	class WPBakeryShortCode_St_Posts_Module extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Posts Grid', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_posts_module',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/post_grid.png',
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Column amount', 'adamas-vc-shortcodes' ),
				'param_name'  => 'column_amount',
				'value'       => array(
					esc_html__( 'One column', 'adamas-vc-shortcodes' )    => 'one-column',
					esc_html__( 'Two columns', 'adamas-vc-shortcodes' )   => 'two-column',
					esc_html__( 'Three columns', 'adamas-vc-shortcodes' ) => 'three-column',
					esc_html__( 'Four columns', 'adamas-vc-shortcodes' )  => 'four-column',
				),
				'description' => esc_html__( 'Select column amount.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Layout', 'adamas-vc-shortcodes' ),
				'param_name'  => 'posts_module_layout',
				'value'       => array(
					esc_html__( 'Grid', 'adamas-vc-shortcodes' )    => 'fitRows',
					esc_html__( 'Masonry', 'adamas-vc-shortcodes' ) => 'masonry',
				),
				'description' => esc_html__( 'Select posts layout. Masonry works only for 2-4 columns.', 'adamas-vc-shortcodes' ),
				'dependency'  => Array(
					'element' => 'column_amount',
					'value'   => array( 'two-column', 'three-column', 'four-column' )
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Columns padding', 'adamas-vc-shortcodes' ),
				'param_name'  => 'column_padding',
				'value'       => array(
					esc_html__( 'No padding', 'adamas-vc-shortcodes' )     => '',
					esc_html__( 'Narrow padding', 'adamas-vc-shortcodes' ) => 'st-narrow-padding',
					esc_html__( 'Normal padding', 'adamas-vc-shortcodes' ) => 'st-normal-padding',
				),
				'description' => esc_html__( 'Select padding between gallery items.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'number',
				'class'       => '',
				'heading'     => esc_html__( 'Items amount', 'adamas-vc-shortcodes' ),
				'param_name'  => 'posts_items_amount',
				'value'       => '',
				'description' => esc_html__( 'Enter number of portfolio items to show.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'checkbox',
				'class'       => '',
				'heading'     => esc_html__( 'Display post date only', 'adamas-vc-shortcodes' ),
				'param_name'  => 'posts_date_only',
				'value'       => array( esc_html__( 'Yes', 'adamas-vc-shortcodes' ) => 'yes' ),
				'description' => esc_html__( 'Check this if you want to display only post date (no author name or comments amount).', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Process Module
	class WPBakeryShortCode_St_Process_Module extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Process Grid Item', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_process_module',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/process_grid_item.png',
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Module Title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_module_title',
				'description' => esc_html__( 'Enter section title.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textarea_html',
				'heading'     => esc_html__( 'Module Description', 'adamas-vc-shortcodes' ),
				'param_name'  => 'content',
				'description' => esc_html__( 'Enter section description.', 'adamas-vc-shortcodes' ),

			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Module content color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_content_color',
				'description' => esc_html__( 'Choose color for content.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background content type', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_bg_select',
				'value'       => array(
					esc_html__( 'Text or number', 'adamas-vc-shortcodes' ) => 'process_select_text',
					esc_html__( 'Icon', 'adamas-vc-shortcodes' )           => 'process_select_icon',
				),
				'description' => esc_html__( 'Select background content type.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Background text or number', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_bg_text',
				'description' => esc_html__( 'Enter background text or number.', 'adamas-vc-shortcodes' ),
				'dependency'  => Array( 'element' => 'process_bg_select', 'value' => array( 'process_select_text' ) ),
			),
			array(
				'type'        => 'icon_manager',
				'class'       => '',
				'heading'     => esc_html__( 'Select Icon', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_bg_icon',
				'value'       => '',
				'description' => esc_html__( "Click and select icon of your choice. If you can't find the one that suits for your purpose", "adamas-vc-shortcodes" ) . ", " . __( "you can", "adamas-vc-shortcodes" ) . " <a href='admin.php?page=bsf-font-icon-manager' target='_blank'>" . __( "add new here", "adamas-vc-shortcodes" ) . "</a>.",
				'dependency'  => Array( 'element' => 'process_bg_select', 'value' => array( 'process_select_icon' ) ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Color in background content (number or icon)', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_bg_content_color',
				'description' => esc_html__( 'Choose color for background content.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Background color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_bg_color',
				'description' => esc_html__( 'Choose background color for this module.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Process Module 2
	class WPBakeryShortCode_St_Process_Module_B extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Process Grid Item B', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_process_module_b',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/process_grid_item_b.png',
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Module Title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_module_title',
				'description' => esc_html__( 'Enter section title.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textarea_html',
				'heading'     => esc_html__( 'Module Description', 'adamas-vc-shortcodes' ),
				'param_name'  => 'content',
				'description' => esc_html__( 'Enter section description.', 'adamas-vc-shortcodes' ),

			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Module content color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_content_color',
				'description' => esc_html__( 'Choose color for content.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'icon_manager',
				'class'       => '',
				'heading'     => esc_html__( 'Select Icon', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_bg_icon',
				'value'       => '',
				'description' => esc_html__( "Click and select icon of your choice. If you can't find the one that suits for your purpose", "adamas-vc-shortcodes" ) . ", " . __( "you can", "adamas-vc-shortcodes" ) . " <a href='admin.php?page=bsf-font-icon-manager' target='_blank'>" . __( "add new here", "adamas-vc-shortcodes" ) . "</a>.",
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Background text or number', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_bg_text',
				'description' => esc_html__( 'Enter background text or number.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Color in background content (number or icon)', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_bg_content_color',
				'description' => esc_html__( 'Choose color for background content.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Background color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_bg_color',
				'description' => esc_html__( 'Choose background color for this module.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'checkbox',
				'class'       => '',
				'heading'     => esc_html__( 'Module margins', 'adamas-vc-shortcodes' ),
				'param_name'  => 'process_margins',
				'description' => esc_html__( 'Check this if you want to set side margins of module.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Product Info
	class WPBakeryShortCode_St_Product_Info extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Product Info', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_product_info',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/product_info.png',
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Content alignment', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_align',
				'description' => esc_html__( 'Set alignment of module content.', 'adamas-vc-shortcodes' ),
				'value'       => array(
					esc_html__( 'Left', 'adamas-vc-shortcodes' )  => 'align-left',
					esc_html__( 'Right', 'adamas-vc-shortcodes' ) => 'align-right',
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Module Title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_title',
				'description' => esc_html__( 'Enter section title.', 'adamas-vc-shortcodes' ),
				'admin_label' => true,
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Module title color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_title_color',
				'description' => esc_html__( 'Choose font color for title.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Module subtitle', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_subtitle',
				'description' => esc_html__( 'Enter section subtitle', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Module subtitle color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_subtitle_color',
				'description' => esc_html__( 'Choose font color for subtitle.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textarea',
				'heading'     => esc_html__( 'Second subtitle', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_desc',
				'description' => esc_html__( 'Enter short description.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Module second subtitle color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_desc_color',
				'description' => esc_html__( 'Choose font color for second subtitle.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textarea_html',
				'heading'     => esc_html__( 'Module description', 'adamas-vc-shortcodes' ),
				'param_name'  => 'content',
				'description' => esc_html__( 'Enter section description.', 'adamas-vc-shortcodes' ),

			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Module description color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_content_color',
				'description' => esc_html__( 'Choose font color for description.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Accents color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_color',
				'description' => esc_html__( 'Choose color for accents.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'vc_link',
				'class'       => '',
				'param_name'  => 'product_info_link',
				'heading'     => esc_html__( 'Link', 'adamas-vc-shortcodes' ),
				'description' => esc_html__( 'Set link for this block.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Link color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'product_info_link_color',
				'description' => esc_html__( 'Choose font color for link.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Pyramid
	class WPBakeryShortCode_St_Pyramid extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Pyramid', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_pyramid',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/pyramid.png',
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Top block background color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'pyramid_bg_top',
				'description' => ''
			),
			array(
				'type'        => 'textfield',
				'class'       => '',
				'heading'     => esc_html__( 'Top block title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'pyramid_title_top',
				'description' => ''
			),
			array(
				'type'        => 'textarea',
				'class'       => '',
				'heading'     => esc_html__( 'Top block description', 'adamas-vc-shortcodes' ),
				'param_name'  => 'pyramid_desc_top',
				'description' => ''
			),
			array(
				'type'        => 'vc_link',
				'class'       => '',
				'param_name'  => 'pyramid_link_top',
				'heading'     => esc_html__( 'Top block link', 'adamas-vc-shortcodes' ),
				'description' => esc_html__( 'Set link for navigation element.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Middle block background color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'pyramid_bg_mid',
				'description' => ''
			),
			array(
				'type'        => 'textfield',
				'class'       => '',
				'heading'     => esc_html__( 'Middle block title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'pyramid_title_mid',
				'description' => ''
			),
			array(
				'type'        => 'textarea',
				'class'       => '',
				'heading'     => esc_html__( 'Middle block description', 'adamas-vc-shortcodes' ),
				'param_name'  => 'pyramid_desc_mid',
				'description' => '',
			),
			array(
				'type'        => 'vc_link',
				'class'       => '',
				'param_name'  => 'pyramid_link_mid',
				'heading'     => esc_html__( 'Middle block link', 'adamas-vc-shortcodes' ),
				'description' => esc_html__( 'Set link for navigation element.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'colorpicker',
				'class'       => '',
				'heading'     => esc_html__( 'Bottom block background color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'pyramid_bg_bot',
				'description' => ''
			),
			array(
				'type'        => 'textfield',
				'class'       => '',
				'heading'     => esc_html__( 'Bottom block title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'pyramid_title_bot',
				'description' => ''
			),
			array(
				'type'        => 'textarea',
				'class'       => '',
				'heading'     => esc_html__( 'Bottom block description', 'adamas-vc-shortcodes' ),
				'param_name'  => 'pyramid_desc_bot',
				'description' => '',
			),
			array(
				'type'        => 'vc_link',
				'class'       => '',
				'param_name'  => 'pyramid_link_bot',
				'heading'     => esc_html__( 'Bottom block', 'adamas-vc-shortcodes' ),
				'description' => esc_html__( 'Set link for navigation element.', 'adamas-vc-shortcodes' ),
			),
		)
	) );

	// Get CF7 for Contact Block
	$cf7 = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );

	$contact_forms = array();
	if ( $cf7 ) {
		foreach ( $cf7 as $cform ) {
			$contact_forms[ $cform->post_title ] = $cform->ID;
		}
	} else {
		$contact_forms[ __( 'No contact forms found', 'adamas-vc-shortcodes' ) ] = 0;
	}

	// Contact Block
	class WPBakeryShortCode_St_Contact_Block extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Contact Block', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_contact_block',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/contact_block.png',
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Block title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'contact_details_title',
				'description' => '',
				'group'       => esc_html__( 'Contact details', 'adamas-vc-shortcodes' )
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Address', 'adamas-vc-shortcodes' ),
				'param_name' => 'contact_details_address',
				'group'      => esc_html__( 'Contact details', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Phone', 'adamas-vc-shortcodes' ),
				'param_name' => 'contact_details_phone',
				'group'      => esc_html__( 'Contact details', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'E-mail', 'adamas-vc-shortcodes' ),
				'param_name' => 'contact_details_email',
				'group'      => esc_html__( 'Contact details', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Schedule', 'adamas-vc-shortcodes' ),
				'param_name' => 'contact_details_schedule',
				'group'      => esc_html__( 'Contact details', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'First column title', 'adamas-vc-shortcodes' ),
				'param_name' => 'table_first',
				'group'      => esc_html__( 'Table', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Second column title', 'adamas-vc-shortcodes' ),
				'param_name' => 'table_second',
				'group'      => esc_html__( 'Table', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Third column title', 'adamas-vc-shortcodes' ),
				'param_name' => 'table_third',
				'group'      => esc_html__( 'Table', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Fourth column title', 'adamas-vc-shortcodes' ),
				'param_name' => 'table_fourth',
				'group'      => esc_html__( 'Table', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Fifth column title', 'adamas-vc-shortcodes' ),
				'param_name' => 'table_fifth',
				'group'      => esc_html__( 'Table', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'param_group',
				'heading'     => esc_html__( 'Table content', 'adamas-vc-shortcodes' ),
				'param_name'  => 'contact_block_table',
				'description' => esc_html__( 'Add table content here.', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Table', 'adamas-vc-shortcodes' ),
				'value'       => urlencode( json_encode( array(
					array(
						'department' => '',
						'name'       => '',
						'phone'      => '',
						'mail'       => '',
						'skype'      => '',
					)
				) ) ),
				'params'      => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'First column', 'adamas-vc-shortcodes' ),
						'param_name'  => 'department',
						'value'       => '',
						'description' => '',
						'admin_label' => true
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Second column', 'adamas-vc-shortcodes' ),
						'param_name'  => 'name',
						'value'       => '',
						'description' => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Third column', 'adamas-vc-shortcodes' ),
						'param_name'  => 'phone',
						'value'       => '',
						'description' => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Fourth column', 'adamas-vc-shortcodes' ),
						'param_name'  => 'mail',
						'value'       => '',
						'description' => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Fifth columm', 'adamas-vc-shortcodes' ),
						'param_name'  => 'skype',
						'value'       => '',
						'description' => '',
					),
				),
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'Facebook link', 'adamas-vc-shortcodes' ),
				'param_name'  => 'social_facebook',
				'description' => '',
				'group'       => esc_html__( 'Socials', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'Twitter link', 'adamas-vc-shortcodes' ),
				'param_name'  => 'social_twitter',
				'description' => '',
				'group'       => esc_html__( 'Socials', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'Google Plus link', 'adamas-vc-shortcodes' ),
				'param_name'  => 'social_googleplus',
				'description' => '',
				'group'       => esc_html__( 'Socials', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'vc_link',
				'heading'    => esc_html__( 'Pinterest link', 'adamas-vc-shortcodes' ),
				'param_name' => 'social_pinterest',
				'group'      => esc_html__( 'Socials', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'vc_link',
				'heading'    => esc_html__( 'LinkedIn link', 'adamas-vc-shortcodes' ),
				'param_name' => 'social_linkedin',
				'group'      => esc_html__( 'Socials', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'vc_link',
				'heading'    => esc_html__( 'Instagram link', 'adamas-vc-shortcodes' ),
				'param_name' => 'social_instagram',
				'group'      => esc_html__( 'Socials', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'vc_link',
				'heading'    => esc_html__( 'VK link', 'adamas-vc-shortcodes' ),
				'param_name' => 'social_vk',
				'group'      => esc_html__( 'Socials', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Image', 'adamas-vc-shortcodes' ),
				'param_name'  => 'contact_block_img',
				'description' => esc_html__( 'Choose image for current block.', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Image', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Contact form title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'contact_form_title',
				'group'       => esc_html__( 'Contact Form', 'adamas-vc-shortcodes' ),
				'description' => '',
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Select contact form', 'adamas-vc-shortcodes' ),
				'param_name'  => 'contact_block_cf_id',
				'value'       => $contact_forms,
				'save_always' => true,
				'description' => esc_html__( 'Choose previously created contact form from the drop down list.', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Contact Form', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Map title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'map_title',
				'group'       => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
				'description' => '',
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Width (in %)', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_width',
				'value'      => '100%',
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Height (in px)', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_height',
				'value'      => '400px',
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Latitude', 'adamas-vc-shortcodes' ),
				'param_name'  => 'map_lat',
				'value'       => '48.8592431',
				'description' => '<a href="http://universimmedia.pagesperso-orange.fr/geo/loc.htm" target="_blank">' . esc_html__( 'Here is a tool', 'adamas-vc-shortcodes' ) . '</a> ' . esc_html__( 'where you can find Latitude & Longitude of your location', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Longitude', 'adamas-vc-shortcodes' ),
				'param_name'  => 'map_lng',
				'value'       => '9.1968686',
				'description' => '<a href="http://universimmedia.pagesperso-orange.fr/geo/loc.htm" target="_blank">' . esc_html__( 'Here is a tool', 'adamas-vc-shortcodes' ) . '</a> ' . esc_html__( 'where you can find Latitude & Longitude of your location', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'heading'    => esc_html__( 'Map type', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_type',
				'value'      => array(
					esc_html__( 'Roadmap', 'adamas-vc-shortcodes' )   => 'ROADMAP',
					esc_html__( 'Satellite', 'adamas-vc-shortcodes' ) => 'SATELLITE',
					esc_html__( 'Hybrid', 'adamas-vc-shortcodes' )    => 'HYBRID',
					esc_html__( 'Terrain', 'adamas-vc-shortcodes' )   => 'TERRAIN'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'heading'    => esc_html__( 'Map Zoom', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_zoom',
				'value'      => array(
					esc_html__( '12 - Default', 'adamas-vc-shortcodes' ) => 12,
					1,
					2,
					3,
					4,
					5,
					6,
					7,
					8,
					9,
					10,
					11,
					13,
					14,
					15,
					16,
					17,
					18,
					19,
					20
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'checkbox',
				'heading'    => '',
				'param_name' => 'map_scrollwheel',
				'value'      => array(
					esc_html__( 'Disable map zoom on mouse wheel scroll', 'adamas-vc-shortcodes' ) => 'disable',
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Street view control', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_streetviewcontrol',
				'value'      => array(
					esc_html__( 'Disable', 'adamas-vc-shortcodes' ) => 'false',
					esc_html__( 'Enable', 'adamas-vc-shortcodes' )  => 'true'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Map type control', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_maptypecontrol',
				'value'      => array(
					esc_html__( 'Disable', 'adamas-vc-shortcodes' ) => 'false',
					esc_html__( 'Enable', 'adamas-vc-shortcodes' )  => 'true'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Zoom control', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_zoomcontrol',
				'value'      => array(
					esc_html__( 'Disable', 'adamas-vc-shortcodes' ) => 'false',
					esc_html__( 'Enable', 'adamas-vc-shortcodes' )  => 'true'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Zoom control size', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_zoomcontrolsize',
				'value'      => array(
					esc_html__( 'Small', 'adamas-vc-shortcodes' ) => 'SMALL',
					esc_html__( 'Large', 'adamas-vc-shortcodes' ) => 'LARGE'
				),
				'dependency' => Array( 'element' => 'map_zoomcontrol', 'value' => array( 'true' ) ),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Disable dragging on Mobile', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_dragging',
				'value'      => array(
					esc_html__( 'Enable', 'adamas-vc-shortcodes' )  => 'true',
					esc_html__( 'Disable', 'adamas-vc-shortcodes' ) => 'false'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Marker/Point icon', 'adamas-vc-shortcodes' ),
				'param_name' => 'marker_icon',
				'value'      => array(
					esc_html__( 'Use Google Default', 'adamas-vc-shortcodes' ) => 'default',
					esc_html__( 'Upload Custom', 'adamas-vc-shortcodes' )      => 'custom'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'ult_img_single',
				'class'       => '',
				'heading'     => esc_html__( 'Upload Image Icon:', 'adamas-vc-shortcodes' ),
				'param_name'  => 'icon_img',
				'value'       => '',
				'description' => esc_html__( 'Upload the custom marker image.', 'adamas-vc-shortcodes' ),
				'dependency'  => Array( 'element' => 'marker_icon', 'value' => array( 'custom' ) ),
				'group'       => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Characteristic
	class WPBakeryShortCode_St_Characteristics_Item extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Characteristics item', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_characteristics_item',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/characteristics_item.png',
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'characteristic_name',
				'admin_label' => true
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Value', 'adamas-vc-shortcodes' ),
				'param_name' => 'characteristic_value',
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Pagination
	class WPBakeryShortCode_St_Pagination_Block extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Pagination block', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_pagination_block',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/pagination.png',
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Brochure
	class WPBakeryShortCode_St_Brochure extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Brochure block', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_brochure',
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/brochure_block.png',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Width', 'adamas-vc-shortcodes' ),
				'param_name'  => 'brochure_width',
				'description' => esc_html__( 'Enter brochure block width (Note: CSS measurement units allowed).', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'brochure_title',
				'description' => '',
				'admin_label' => true,
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Link', 'adamas-vc-shortcodes' ),
				'param_name'  => 'brochure_link',
				'description' => '',
			),
			array(
				'type'       => 'checkbox',
				'heading'    => esc_html__( 'Open link in new tab', 'adamas-vc-shortcodes' ),
				'param_name' => 'target_blank',
			),
			array(
				'type'        => 'colorpicker',
				'heading'     => esc_html__( 'Title color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'brochure_title_color',
				'description' => '',
			),
			array(
				'type'        => 'colorpicker',
				'heading'     => esc_html__( 'Title color on hover', 'adamas-vc-shortcodes' ),
				'param_name'  => 'brochure_title_color_hover',
				'description' => '',
			),
			array(
				'type'        => 'colorpicker',
				'heading'     => esc_html__( 'Background color', 'adamas-vc-shortcodes' ),
				'param_name'  => 'brochure_bg_color',
				'description' => '',
			),
			array(
				'type'        => 'colorpicker',
				'heading'     => esc_html__( 'Background color on hover', 'adamas-vc-shortcodes' ),
				'param_name'  => 'brochure_bg_color_hover',
				'description' => '',
			),
			array(
				'type'       => 'checkbox',
				'heading'    => esc_html__( 'Hide file extension ', 'adamas-vc-shortcodes' ),
				'param_name' => 'brochure_hide_extension',
			),
			array(
				'type'       => 'checkbox',
				'heading'    => esc_html__( 'Hide file size', 'adamas-vc-shortcodes' ),
				'param_name' => 'brochure_hide_size',
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
			),
		)
	) );

	// Breadcrumb
	class WPBakeryShortCode_St_Breadcrumbs extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Breadcrumbs', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_breadcrumbs',
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/breadcrumbs.png',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Breadcrumbs background check', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_breadcrumbs_bg_check',
				'description' => esc_html__( 'Check this if breadcrumbs placed on dark background.', 'adamas-vc-shortcodes' ),
				'value'       => array( esc_html__( 'Yes', 'adamas-vc-shortcodes' ) => 'yes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' ),
			),
		)
	) );

	// Simple Link
	class WPBakeryShortCode_St_Simple_Link extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Simple Link', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_simple_link',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/simple_link.png',
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_simple_link_title',
				'admin_label' => true,
				'description' => '',
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'Link', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_simple_link_link',
				'description' => esc_html__( 'Add a custom link or select existing page. You can remove existing link as well.', 'adamas-vc-shortcodes' )
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Link Alignment', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_simple_link_alignment',
				'description' => esc_html__( 'Select the text align for link.', 'adamas-vc-shortcodes' ),
				'value'       => array(
					esc_html__( 'Center', 'adamas-vc-shortcodes' ) => 'text-center',
					esc_html__( 'Left', 'adamas-vc-shortcodes' )   => 'text-left',
					esc_html__( 'Right', 'adamas-vc-shortcodes' )  => 'text-right',
				),
			),
			array(
				'type'        => 'checkbox',
				'class'       => '',
				'heading'     => esc_html__( 'Background check', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_simple_link_dark_bg',
				'description' => esc_html__( 'Check this if this link placed on dark background.', 'adamas-vc-shortcodes' ),
				'value'       => array( esc_html__( 'Yes', 'adamas-vc-shortcodes' ) => 'yes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' ),
			),
		)
	) );

	class WPBakeryShortCode_St_Mini_Service_Box extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Mini Service Box', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_mini_service_box',
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/mini_service_box.png',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_mini_service_box_title',
				'admin_label' => true,
				'description' => '',
			),
			array(
				'type'        => 'textarea',
				'heading'     => esc_html__( 'Description', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_mini_service_box_desc',
				'description' => '',
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'Link', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_mini_service_box_link',
				'description' => esc_html__( 'Add a custom link or select existing page. You can remove existing link as well.', 'adamas-vc-shortcodes' )
			),
			array(
				'type'        => 'attach_image',
				'class'       => '',
				'heading'     => esc_html__( 'Background image', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_mini_service_box_image',
				'value'       => '',
				'description' => esc_html__( 'Set background image for section.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'icon_manager',
				'class'       => '',
				'heading'     => esc_html__( 'Select Icon', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_mini_service_box_icon',
				'value'       => '',
				'description' => esc_html__( "Click and select icon of your choice. If you can't find the one that suits for your purpose", "adamas-vc-shortcodes" ) . ", " . esc_html__( "you can", "adamas-vc-shortcodes" ) . " <a href='admin.php?page=bsf-font-icon-manager' target='_blank'>" . esc_html__( "add new here", "adamas-vc-shortcodes" ) . "</a>.",
			),
			array(
				'type'        => 'dropdown',
				'class'       => '',
				'heading'     => esc_html__( 'Animation', 'adamas-vc-shortcodes' ),
				'param_name'  => 'module_animation',
				'value'       => st_adamas_animations_list(),
				'description' => esc_html__( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' ),
			),
		)
	) );

	// Map with selects
	class WPBakeryShortCode_St_Map_Select extends WPBakeryShortCodesContainer {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Map with select', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_map_select',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/map_with_select.png',
		'as_parent'               => array( 'only' => 'st_map_select_item' ),
		'content_element'         => true,
		'show_settings_on_create' => true,
		'js_view'                 => 'VcColumnView',
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Message text (e.g. "Find your nearest dealer").', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_map_select_text',
				'description' => '',
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Placeholder for parent select.', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_map_select_parent_placeholder',
				'description' => '',
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Placeholder for child select.', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_map_select_child_placeholder',
				'description' => '',
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Height (in px)', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_height',
				'value'      => '600px',
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'heading'    => esc_html__( 'Map type', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_type',
				'value'      => array(
					esc_html__( 'Roadmap', 'adamas-vc-shortcodes' )   => 'ROADMAP',
					esc_html__( 'Satellite', 'adamas-vc-shortcodes' ) => 'SATELLITE',
					esc_html__( 'Hybrid', 'adamas-vc-shortcodes' )    => 'HYBRID',
					esc_html__( 'Terrain', 'adamas-vc-shortcodes' )   => 'TERRAIN'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'heading'    => esc_html__( 'Map Color Scheme', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_colors',
				'value'      => array(
					esc_html__( 'Standard', 'adamas-vc-shortcodes' )  => '',
					esc_html__( 'Silver', 'adamas-vc-shortcodes' )    => 'silver',
					esc_html__( 'Retro', 'adamas-vc-shortcodes' )     => 'retro',
					esc_html__( 'Dark', 'adamas-vc-shortcodes' )      => 'dark',
					esc_html__( 'Night', 'adamas-vc-shortcodes' )     => 'night',
					esc_html__( 'Aubergine', 'adamas-vc-shortcodes' ) => 'aubergine',
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'map_type', 'value' => array( 'ROADMAP' ) ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Map Min Zoom', 'adamas-vc-shortcodes' ),
				'param_name'  => 'map_min_zoom',
				'value'       => array(
					esc_html__( '16 - Default', 'adamas-vc-shortcodes' ) => 16,
					1,
					2,
					3,
					4,
					5,
					6,
					7,
					8,
					9,
					10,
					11,
					12,
					13,
					14,
					15,
					17,
					18,
					19,
					20
				),
				'description' => esc_html__( 'Minimum zoom for map when clicking on single marker or selecting single option.', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'checkbox',
				'heading'    => '',
				'param_name' => 'map_scrollwheel',
				'value'      => array(
					esc_html__( 'Disable map zoom on mouse wheel scroll', 'adamas-vc-shortcodes' ) => 'disable',
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Street view control', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_streetviewcontrol',
				'value'      => array(
					esc_html__( 'Disable', 'adamas-vc-shortcodes' ) => 'false',
					esc_html__( 'Enable', 'adamas-vc-shortcodes' )  => 'true'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Map type control', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_maptypecontrol',
				'value'      => array(
					esc_html__( 'Disable', 'adamas-vc-shortcodes' ) => 'false',
					esc_html__( 'Enable', 'adamas-vc-shortcodes' )  => 'true'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Zoom control', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_zoomcontrol',
				'value'      => array(
					esc_html__( 'Disable', 'adamas-vc-shortcodes' ) => 'false',
					esc_html__( 'Enable', 'adamas-vc-shortcodes' )  => 'true'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Zoom control size', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_zoomcontrolsize',
				'value'      => array(
					esc_html__( 'Small', 'adamas-vc-shortcodes' ) => 'SMALL',
					esc_html__( 'Large', 'adamas-vc-shortcodes' ) => 'LARGE'
				),
				'dependency' => Array( 'element' => 'map_zoomcontrol', 'value' => array( 'true' ) ),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Disable dragging on Mobile', 'adamas-vc-shortcodes' ),
				'param_name' => 'map_dragging',
				'value'      => array(
					esc_html__( 'Enable', 'adamas-vc-shortcodes' )  => 'true',
					esc_html__( 'Disable', 'adamas-vc-shortcodes' ) => 'false'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Marker/Point icon', 'adamas-vc-shortcodes' ),
				'param_name' => 'marker_icon',
				'value'      => array(
					esc_html__( 'Use Google Default', 'adamas-vc-shortcodes' ) => 'default',
					esc_html__( 'Upload Custom', 'adamas-vc-shortcodes' )      => 'custom'
				),
				'group'      => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'attach_image',
				'class'       => '',
				'heading'     => esc_html__( 'Upload Image Icon:', 'adamas-vc-shortcodes' ),
				'param_name'  => 'icon_img',
				'value'       => '',
				'description' => esc_html__( 'Upload the custom marker image.', 'adamas-vc-shortcodes' ),
				'dependency'  => Array( 'element' => 'marker_icon', 'value' => array( 'custom' ) ),
				'group'       => esc_html__( 'Google Map', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' ),
			),
		)
	) );

	// Map with Select - Group Select
	class WPBakeryShortCode_St_Map_Select_Item extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Select group', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_map_select_item',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/map_with_select.png',
		'show_settings_on_create' => true,
		'as_child'                => array( 'only' => 'st_map_select' ),
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Group title', 'adamas-vc-shortcodes' ),
				'param_name'  => 'st_map_select_group_title',
				'admin_label' => true,
				'description' => '',
			),
			array(
				'type'        => 'param_group',
				'heading'     => '',
				'param_name'  => 'st_map_select_group',
				'description' => esc_html__( 'Add options here.', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Options', 'adamas-vc-shortcodes' ),
				'value'       => urlencode( json_encode( array(
					array(
						'title'    => '',
						'subtitle' => '',
						'lat'      => '',
						'lng'      => '',
						'address'  => '',
						'phone'    => '',
						'email'    => '',
						'schedule' => '',
					)
				) ) ),
				'params'      => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'adamas-vc-shortcodes' ),
						'param_name'  => 'title',
						'value'       => '',
						'description' => '',
						'admin_label' => true
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Subtitle', 'adamas-vc-shortcodes' ),
						'param_name'  => 'subtitle',
						'value'       => '',
						'description' => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Latitude', 'adamas-vc-shortcodes' ),
						'param_name'  => 'lat',
						'value'       => '',
						'description' => '<a href="http://universimmedia.pagesperso-orange.fr/geo/loc.htm" target="_blank">' . esc_html__( 'Here is a tool', 'adamas-vc-shortcodes' ) . '</a> ' . esc_html__( 'where you can find Latitude & Longitude of your location', 'adamas-vc-shortcodes' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Longitude', 'adamas-vc-shortcodes' ),
						'param_name'  => 'lng',
						'value'       => '',
						'description' => '<a href="http://universimmedia.pagesperso-orange.fr/geo/loc.htm" target="_blank">' . esc_html__( 'Here is a tool', 'adamas-vc-shortcodes' ) . '</a> ' . esc_html__( 'where you can find Latitude & Longitude of your location', 'adamas-vc-shortcodes' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Address', 'adamas-vc-shortcodes' ),
						'param_name'  => 'address',
						'value'       => '',
						'description' => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Phone', 'adamas-vc-shortcodes' ),
						'param_name'  => 'phone',
						'value'       => '',
						'description' => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'E-mail', 'adamas-vc-shortcodes' ),
						'param_name'  => 'email',
						'value'       => '',
						'description' => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Schedule', 'adamas-vc-shortcodes' ),
						'param_name'  => 'schedule',
						'value'       => '',
						'description' => '',
					),
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' ),
			),
		)
	) );

	// Full Width Carousel
	class WPBakeryShortCode_St_Full_Width_Carousel extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Full Width Carousel', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_full_width_carousel',
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/full_width_carousel.png',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'param_group',
				'heading'     => '',
				'param_name'  => 'st_full_width_carousel_data',
				'description' => esc_html__( 'Add slides here.', 'adamas-vc-shortcodes' ),
				'value'       => urlencode( json_encode( array(
					array(
						'image'    => '',
						'link'     => '',
						'title'    => '',
						'subtitle' => '',
						'desc'     => '',
					)
				) ) ),
				'params'      => array(
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'adamas-vc-shortcodes' ),
						'param_name'  => 'image',
						'description' => '',
					),
					array(
						'type'       => 'vc_link',
						'heading'    => esc_html__( 'Link', 'adamas-vc-shortcodes' ),
						'param_name' => 'link',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'adamas-vc-shortcodes' ),
						'param_name'  => 'title',
						'value'       => '',
						'description' => '',
						'admin_label' => true
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Subtitle', 'adamas-vc-shortcodes' ),
						'param_name'  => 'subtitle',
						'value'       => '',
						'description' => '',
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Description', 'adamas-vc-shortcodes' ),
						'param_name'  => 'desc',
						'value'       => '',
						'description' => '',
					),
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' ),
			),
		)
	) );

	// Video Popup
	class WPBakeryShortCode_St_Video_Popup extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Video Popup', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_video_popup',
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/video_box.png',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Video Source', 'adamas-vc-shortcodes' ),
				'param_name'  => 'video_source',
				'description' => esc_html__( 'Select video source.', 'adamas-vc-shortcodes' ),
				'value'       => array(
					esc_html__( 'Media Library', 'adamas-vc-shortcodes' ) => 'media',
					esc_html__( 'YouTube', 'adamas-vc-shortcodes' )       => 'youtube',
					esc_html__( 'Vimeo', 'adamas-vc-shortcodes' )         => 'vimeo',
				),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'MP4 Video Link', 'adamas-vc-shortcodes' ),
				'param_name' => 'mp4_video',
				'dependency' => Array( 'element' => 'video_source', 'value' => array( 'media' ) ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'WebM/Ogg Video Link', 'adamas-vc-shortcodes' ),
				'param_name' => 'webm_video',
				'dependency' => Array( 'element' => 'video_source', 'value' => array( 'media' ) ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'YouTube Video Link', 'adamas-vc-shortcodes' ),
				'param_name' => 'youtube_video',
				'dependency' => Array( 'element' => 'video_source', 'value' => array( 'youtube' ) ),
			),
			array(
				'type'       => 'textfield',
				'heading'    => esc_html__( 'Vimeo Video Link', 'adamas-vc-shortcodes' ),
				'param_name' => 'vimeo_video',
				'dependency' => Array( 'element' => 'video_source', 'value' => array( 'vimeo' ) ),
			),
			array(
				'type'        => 'dropdown',
				'class'       => '',
				'heading'     => esc_html__( 'Select Icon Type', 'adamas-vc-shortcodes' ),
				'param_name'  => 'icon_type',
				'description' => esc_html__( 'Select icon type for "Play" button', 'adamas-vc-shortcodes' ),
				'value'       => array(
					esc_html__( 'Font Icon', 'adamas-vc-shortcodes' )  => 'font-icon',
					esc_html__( 'Image Icon', 'adamas-vc-shortcodes' ) => 'image-icon',
				),
				'group'       => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'icon_manager',
				'class'       => '',
				'heading'     => esc_html__( 'Select Icon', 'adamas-vc-shortcodes' ),
				'param_name'  => 'icon',
				'description' => esc_html__( 'Select icon for "Play" button', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency'  => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'attach_image',
				'class'      => '',
				'heading'    => esc_html__( 'Select Image Icon', 'adamas-vc-shortcodes' ),
				'param_name' => 'icon_img',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'image-icon' ) ),
			),
			array(
				'type'       => 'number',
				'class'      => '',
				'heading'    => esc_html__( 'Set Image Icon width', 'adamas-vc-shortcodes' ),
				'param_name' => 'icon_img_width',
				'suffix'     => 'px',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'image-icon' ) ),
			),
			array(
				'type'       => 'number',
				'class'      => '',
				'heading'    => esc_html__( 'Icon Size', 'adamas-vc-shortcodes' ),
				'param_name' => 'icon_size',
				'suffix'     => 'px',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'colorpicker',
				'class'      => '',
				'heading'    => esc_html__( 'Icon Color', 'adamas-vc-shortcodes' ),
				'param_name' => 'icon_color',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'number',
				'class'      => '',
				'heading'    => esc_html__( 'Icon Background Size', 'adamas-vc-shortcodes' ),
				'param_name' => 'icon_bg_size',
				'suffix'     => 'px',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'colorpicker',
				'class'      => '',
				'heading'    => esc_html__( 'Icon Background Color', 'adamas-vc-shortcodes' ),
				'param_name' => 'icon_bg_color',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'number',
				'class'      => '',
				'heading'    => esc_html__( 'Border Radius', 'adamas-vc-shortcodes' ),
				'param_name' => 'border_radius',
				'suffix'     => 'px',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'dropdown',
				'class'      => '',
				'heading'    => esc_html__( 'Border Style', 'adamas-vc-shortcodes' ),
				'param_name' => 'border_style',
				'value'      => array(
					esc_html__( 'None', 'adamas-vc-shortcodes' )   => 'none',
					esc_html__( 'Solid', 'adamas-vc-shortcodes' )  => 'solid',
					esc_html__( 'Dotted', 'adamas-vc-shortcodes' ) => 'dotted',
					esc_html__( 'Dashed', 'adamas-vc-shortcodes' ) => 'dashed',
					esc_html__( 'Double', 'adamas-vc-shortcodes' ) => 'double',
					esc_html__( 'Groove', 'adamas-vc-shortcodes' ) => 'groove',
					esc_html__( 'Ridge', 'adamas-vc-shortcodes' )  => 'ridge',
					esc_html__( 'Inset', 'adamas-vc-shortcodes' )  => 'inset',
					esc_html__( 'Outset', 'adamas-vc-shortcodes' ) => 'outset',
				),
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'number',
				'class'      => '',
				'heading'    => esc_html__( 'Border Width', 'adamas-vc-shortcodes' ),
				'param_name' => 'border_width',
				'suffix'     => 'px',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'colorpicker',
				'class'      => '',
				'heading'    => esc_html__( 'Border Color', 'adamas-vc-shortcodes' ),
				'param_name' => 'border_color',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'colorpicker',
				'class'      => '',
				'heading'    => esc_html__( 'Icon Color on hover', 'adamas-vc-shortcodes' ),
				'param_name' => 'icon_color_hover',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'colorpicker',
				'class'      => '',
				'heading'    => esc_html__( 'Background Color on hover', 'adamas-vc-shortcodes' ),
				'param_name' => 'bg_color_hover',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'       => 'colorpicker',
				'class'      => '',
				'heading'    => esc_html__( 'Border Color on hover', 'adamas-vc-shortcodes' ),
				'param_name' => 'border_color_hover',
				'group'      => esc_html__( 'Icon', 'adamas-vc-shortcodes' ),
				'dependency' => Array( 'element' => 'icon_type', 'value' => array( 'font-icon' ) ),
			),
			array(
				'type'        => 'attach_image',
				'class'       => '',
				'heading'     => esc_html__( 'Image', 'adamas-vc-shortcodes' ),
				'param_name'  => 'bg_image',
				'value'       => '',
				'description' => esc_html__( 'Set background image used for this section.', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Background Image', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'class'       => '',
				'heading'     => esc_html__( 'Image width', 'adamas-vc-shortcodes' ),
				'param_name'  => 'image_width',
				'description' => esc_html__( 'Set image width using CSS values - px, %, etc.', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Background Image', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'class'       => '',
				'heading'     => esc_html__( 'Image height', 'adamas-vc-shortcodes' ),
				'param_name'  => 'image_height',
				'description' => esc_html__( 'Set image height using CSS values - px, %, etc.', 'adamas-vc-shortcodes' ),
				'group'       => esc_html__( 'Background Image', 'adamas-vc-shortcodes' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' ),
			),
		)
	) );

	// Sharing Module
	class WPBakeryShortCode_St_Sharing extends WPBakeryShortCode {
	}

	vc_map( array(
		'name'                    => esc_html__( 'Sharing', 'adamas-vc-shortcodes' ),
		'base'                    => 'st_sharing',
		'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/sharing_block.png',
		'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
		'show_settings_on_create' => true,
		'params'                  => array(
			array(
				'type'       => 'dropdown',
				'heading'    => esc_html__( 'Layout', 'adamas-vc-shortcodes' ),
				'param_name' => 'sharing_layout',
				'value'      => array(
					esc_html__( 'Circle buttons with icons', 'adamas-vc-shortcodes' )         => 'style-1',
					esc_html__( 'Square buttons with icons', 'adamas-vc-shortcodes' )         => 'style-2',
					esc_html__( 'Large buttons with icons and text', 'adamas-vc-shortcodes' ) => 'style-3',
				),
			),
			array(
				'type'       => 'dropdown',
				'heading'    => esc_html__( 'Alignment', 'adamas-vc-shortcodes' ),
				'param_name' => 'sharing_alignment',
				'value'      => array(
					esc_html__( 'Left', 'adamas-vc-shortcodes' )   => 'left',
					esc_html__( 'Center', 'adamas-vc-shortcodes' ) => 'center',
					esc_html__( 'Right', 'adamas-vc-shortcodes' )  => 'right',
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Enable sharing counts', 'adamas-vc-shortcodes' ),
				'param_name'  => 'sharing_count',
				'description' => esc_html__( 'Check this if you want to show counts with sharing buttons.', 'adamas-vc-shortcodes' ),
				'value'       => array( esc_html__( 'Yes', 'adamas-vc-shortcodes' ) => 'yes' ),
			),
			array(
				'type'       => 'checkbox',
				'heading'    => esc_html__( 'Socials to share', 'adamas-vc-shortcodes' ),
				'param_name' => 'sharing_config',
				'value'      => array(
					esc_html__( 'By e-mail', 'adamas-vc-shortcodes' )   => 'email',
					esc_html__( 'Twitter', 'adamas-vc-shortcodes' )     => 'twitter',
					esc_html__( 'Facebook', 'adamas-vc-shortcodes' )    => 'facebook',
					esc_html__( 'Google Plus', 'adamas-vc-shortcodes' ) => 'googleplus',
					esc_html__( 'Linked In', 'adamas-vc-shortcodes' )   => 'linkedin',
					esc_html__( 'Pinterest', 'adamas-vc-shortcodes' )   => 'pinterest',
					esc_html__( 'WhatsApp', 'adamas-vc-shortcodes' )    => 'whatsapp',
					esc_html__( 'Viber', 'adamas-vc-shortcodes' )       => 'viber',
					esc_html__( 'Messenger', 'adamas-vc-shortcodes' )   => 'messenger',
					esc_html__( 'VKontakte', 'adamas-vc-shortcodes' )   => 'vkontakte',
					esc_html__( 'Telegram', 'adamas-vc-shortcodes' )    => 'telegram',
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'adamas-vc-shortcodes' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' ),
			),
		)
	) );
}
