<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'yourprefix_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category YourThemeOrPlugin
 * @package  Demo_CMB2
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */

/**
 * Get the bootstrap!
 */
if ( file_exists( get_theme_file_path( '/includes/lib/cmb/init.php' ) ) ) {
	require_once get_theme_file_path( '/includes/lib/cmb/init.php' );
} elseif ( get_theme_file_path( '/includes/lib/cmb/init.php' ) ) {
	require_once get_theme_file_path( '/includes/lib/cmb/init.php' );
}

/**
 * Conditionally displays a metabox when used as a callback in the 'show_on_cb' cmb2_box parameter
 *
 * @param  CMB2 object $cmb CMB2 object
 *
 * @return bool             True if metabox should show
 */
function st_adamas_show_if_front_page( $cmb ) {
	// Don't show this metabox if it's not the front page template
	if ( $cmb->object_id !== get_option( 'page_on_front' ) ) {
		return false;
	}

	return true;
}

/**
 * Conditionally displays a field when used as a callback in the 'show_on_cb' field parameter
 *
 * @param  CMB2_Field object $field Field object
 *
 * @return bool                     True if metabox should show
 */
function st_adamas_hide_if_no_cats( $field ) {
	// Don't show this field if not in the cats category
	if ( ! has_tag( 'cats', $field->object_id ) ) {
		return false;
	}

	return true;
}

function cmb_show_on_post_format( $display, $post_format ) {
	if ( ! isset( $post_format['show_on']['key'] ) ) {
		return $display;
	}
	$post_id = 0;
	// If we're showing it based on ID, get the current ID
	if ( isset( $_GET['post'] ) ) {
		$post_id = $_GET['post'];
	} elseif ( isset( $_POST['post_ID'] ) ) {
		$post_id = $_POST['post_ID'];
	}
	if ( ! $post_id ) {
		return $display;
	}
	$value = get_post_format( $post_id );

	if ( empty( $post_format['show_on']['key'] ) ) {
		return (bool) $value;
	}

	return $value == $post_format['show_on']['value'];
}

add_filter( 'cmb2_show_on', 'cmb_show_on_post_format', 10, 2 );


// Title settings
add_action( 'cmb2_admin_init', 'st_adamas_title_settings_metabox' );

function st_adamas_title_settings_metabox() {
	$prefix = 'st_';

	$title_settings = new_cmb2_box( array(
		'id'           => $prefix . 'title_settings',
		'title'        => esc_html__( 'Page Settings', 'adamas' ),
		'object_types' => array( 'page', 'post', 'projects' ),
	) );

	$title_settings->add_field( array(
		'name'             => esc_html__( 'Transparent Header', 'adamas' ),
		'id'               => $prefix . 'transparent_header',
		'type'             => 'radio',
		'show_option_none' => false,
		'default'          => 'disable',
		'options'          => array(
			'enable'  => esc_html__( 'Enable', 'adamas' ),
			'disable' => esc_html__( 'Disable', 'adamas' ),
		),
	) );

	$title_settings->add_field( array(
		'name'             => esc_html__( 'Title container', 'adamas' ),
		'id'               => $prefix . 'title_container',
		'type'             => 'select',
		'show_option_none' => false,
		'default'          => 'enable',
		'options'          => array(
			'enable'  => esc_html__( 'Enable', 'adamas' ),
			'disable' => esc_html__( 'Disable', 'adamas' ),
		),
	) );

	$title_settings->add_field( array(
		'name'             => esc_html__( 'Title container height', 'adamas' ),
		'id'               => $prefix . 'title_container_height',
		'type'             => 'select',
		'show_option_none' => false,
		'default'          => 'standard',
		'options'          => array(
			'standard' => esc_html__( 'Standard', 'adamas' ),
			'enlarged' => esc_html__( 'Enlarged', 'adamas' ),
		),
	) );

	$title_settings->add_field( array(
		'name' => esc_html__( 'Title container overlay color', 'adamas' ),
		'id'   => $prefix . 'title_container_overlay_color',
		'type' => 'colorpicker',
	) );

	$title_settings->add_field( array(
		'name' => esc_html__( 'Subtitle', 'adamas' ),
		'desc' => esc_html__( 'Enter subtitle for this page (optional).', 'adamas' ),
		'id'   => $prefix . 'page_title_subtitle',
		'type' => 'text',
	) );

	$title_settings->add_field( array(
		'name'    => esc_html__( 'Title, subtitle and breadcrumb trail color', 'adamas' ),
		'desc'    => esc_html__( 'Select color for title, subtitle and breadcrumb trail.', 'adamas' ),
		'id'      => $prefix . 'page_title_color',
		'type'    => 'colorpicker',
		'default' => '#ffffff',
	) );

	$title_settings->add_field( array(
		'name'    => esc_html__( 'Title alignment', 'adamas' ),
		'desc'    => esc_html__( 'Set alignment for page title and subtitle.', 'adamas' ),
		'id'      => $prefix . 'page_title_align',
		'type'    => 'select',
		'default' => 'left',
		'options' => array(
			'left'   => esc_html__( 'Left', 'adamas' ),
			'center' => esc_html__( 'Center', 'adamas' ),
			'right'  => esc_html__( 'Right', 'adamas' ),
		),
	) );

}

// Single post
add_action( 'cmb2_admin_init', 'st_adamas_single_post_metabox' );

function st_adamas_single_post_metabox() {
	$prefix = 'st_single_post_';

	$single_post = new_cmb2_box( array(
		'id'           => $prefix . 'settings',
		'title'        => esc_html__( 'Post page settings', 'adamas' ),
		'object_types' => array( 'post' ),
	) );

	$single_post->add_field( array(
		'name'             => esc_html__( 'Page width', 'adamas' ),
		'desc'             => esc_html__( 'Select page width (standard - 1200px, full-width - full screen width).', 'adamas' ),
		'id'               => $prefix . 'width',
		'type'             => 'select',
		'show_option_none' => false,
		'options'          => array(
			'default'    => esc_html__( 'Theme defaults', 'adamas' ),
			'standard'   => esc_html__( 'Standard', 'adamas' ),
			'full-width' => esc_html__( 'Full-width', 'adamas' ),
		),
	) );

	$single_post->add_field( array(
		'name'             => esc_html__( 'Sidebar', 'adamas' ),
		'desc'             => esc_html__( 'Set sidebars for this page', 'adamas' ),
		'id'               => $prefix . 'sidebar',
		'type'             => 'select',
		'show_option_none' => false,
		'options'          => array(
			'default' => esc_html__( 'Theme defaults', 'adamas' ),
			'none'    => esc_html__( 'No sidebar', 'adamas' ),
			'left'    => esc_html__( 'Left sidebar', 'adamas' ),
			'right'   => esc_html__( 'Right sidebar', 'adamas' ),
			'both'    => esc_html__( 'Both sidebars', 'adamas' ),
		),
	) );

}

// Video post
add_action( 'cmb2_admin_init', 'st_adamas_video_post_metabox' );

function st_adamas_video_post_metabox() {
	$prefix = 'st_video_post_';

	$video_post = new_cmb2_box( array(
		'id'           => $prefix . '_settings',
		'title'        => esc_html__( 'Video Post Settings', 'adamas' ),
		'object_types' => array( 'post' ),
		'show_on'      => array( 'key' => 'post_format', 'value' => 'video' ),
	) );

	$video_post->add_field( array(
		'name' => esc_html__( 'Video URL', 'adamas' ),
		'desc' => wp_kses( __( 'Supports services listed at <a href="http://codex.wordpress.org/Embeds">http://codex.wordpress.org/Embeds</a>.', 'adamas' ), array( 'a' => array( 'href' => array() ) ) ),
		'id'   => $prefix . 'video_url',
		'type' => 'oembed',
	) );

}

// Audio post
add_action( 'cmb2_admin_init', 'st_adamas_audio_post_metabox' );

function st_adamas_audio_post_metabox() {
	$prefix = 'st_audio_post_';

	$audio_post = new_cmb2_box( array(
		'id'           => $prefix . '_settings',
		'title'        => esc_html__( 'Audio Post Settings', 'adamas' ),
		'object_types' => array( 'post' ),
		'show_on'      => array( 'key' => 'post_format', 'value' => 'audio' ),
	) );

	$audio_post->add_field( array(
		'name' => esc_html__( 'Audio URL', 'adamas' ),
		'desc' => wp_kses( __( 'Supports services listed at <a href="http://codex.wordpress.org/Embeds">http://codex.wordpress.org/Embeds</a>.', 'adamas' ), array( 'a' => array( 'href' => array() ) ) ),
		'id'   => $prefix . 'audio_url',
		'type' => 'oembed',
	) );

}

// Quote post
add_action( 'cmb2_admin_init', 'st_adamas_quote_post_metabox' );

function st_adamas_quote_post_metabox() {
	$prefix = 'st_quote_post_';

	$quote_post = new_cmb2_box( array(
		'id'           => $prefix . '_settings',
		'title'        => esc_html__( 'Quote Post Settings', 'adamas' ),
		'object_types' => array( 'post' ),
		'show_on'      => array( 'key' => 'post_format', 'value' => 'quote' ),
	) );

	$quote_post->add_field( array(
		'name' => esc_html__( 'Quote Author', 'adamas' ),
		'desc' => esc_html__( 'Please, enter quote author name.', 'adamas' ),
		'id'   => $prefix . 'author',
		'type' => 'text',
	) );

}

// Gallery post
add_action( 'cmb2_admin_init', 'st_adamas_gallery_post_metabox' );

function st_adamas_gallery_post_metabox() {
	$prefix = 'st_gallery_post_';

	$gallery_post = new_cmb2_box( array(
		'id'           => $prefix . '_settings',
		'title'        => esc_html__( 'Gallery Post Settings', 'adamas' ),
		'object_types' => array( 'post' ),
		'show_on'      => array( 'key' => 'post_format', 'value' => 'gallery' ),
	) );

	$gallery_post->add_field( array(
		'name'         => esc_html__( 'Gallery Images', 'adamas' ),
		'desc'         => '',
		'id'           => $prefix . 'images',
		'type'         => 'file_list',
		'preview_size' => array( 100, 100 ), // Default: array( 50, 50 )
	) );
}

// Testimonials
add_action( 'cmb2_admin_init', 'st_adamas_testimonials_metabox' );

function st_adamas_testimonials_metabox() {
	$prefix = 'st_testimonials_';

	$testimonials = new_cmb2_box( array(
		'id'           => $prefix . '_info',
		'title'        => esc_html__( 'Testimonial info', 'adamas' ),
		'object_types' => array( 'testimonials' ),
	) );

	$testimonials->add_field( array(
		'name' => esc_html__( 'Client position', 'adamas' ),
		'desc' => '',
		'id'   => $prefix . 'position',
		'type' => 'text',
	) );

	$testimonials->add_field( array(
		'name' => esc_html__( 'Client company name', 'adamas' ),
		'desc' => '',
		'id'   => $prefix . 'company_name',
		'type' => 'text',
	) );

	$testimonials->add_field( array(
		'name'    => esc_html__( 'Company logo', 'adamas' ),
		'desc'    => '',
		'id'      => $prefix . 'company_logo',
		'type'    => 'file',
		'options' => array(
			'url' => false,
		),
	) );
}

// Single project
add_action( 'cmb2_admin_init', 'st_adamas_single_project_metabox' );

function st_adamas_single_project_metabox() {
	$prefix = 'st_';

	$projects = new_cmb2_box( array(
		'id'           => $prefix . '_single_project_metabox',
		'title'        => esc_html__( 'Single project settings', 'adamas' ),
		'object_types' => array( 'projects' )
	) );

	$projects->add_field( array(
		'name' => esc_html__( 'Custom URL', 'adamas' ),
		'desc' => esc_html__( 'Set custom link for this project. Please, use full URL (e.g, "https://slimtemplate.net/adamas-wordpress/").', 'adamas' ),
		'id'   => $prefix . 'landing_url',
		'type' => 'text_url',
	) );

	$projects->add_field( array(
		'name' => esc_html__( 'Disable URL', 'adamas' ),
		'desc' => esc_html__( 'Disable link for this project (will be displayed as simple grid).', 'adamas' ),
		'id'   => $prefix . 'landing_disable_url',
		'type' => 'checkbox',
	) );

}