<?php
/**
 * Cart totals
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart-totals.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see        https://docs.woocommerce.com/document/template-structure/
 * @author        WooThemes
 * @package    WooCommerce/Templates
 * @version     2.3.6
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

?>
<div class="cart_totals <?php if ( wc()->customer->has_calculated_shipping() ) {
	echo 'calculated_shipping';
} ?>">

	<?php do_action( 'woocommerce_before_cart_totals' ); ?>

    <h2><i class="st-h-before"><i></i><i><i></i></i><i></i><i></i></i><?php esc_html_e( 'Cart Totals', 'adamas' ); ?><i class="st-h-after"><i></i></i></h2>

    <table cellspacing="0" class="shop_table shop_table_responsive">

        <tr class="cart-subtotal">
            <th><?php esc_html_e( 'Subtotal', 'adamas' ); ?></th>
            <td data-title="<?php esc_attr_e( 'Subtotal', 'adamas' ); ?>"><?php wc_cart_totals_subtotal_html(); ?></td>
        </tr>

		<?php foreach ( wc()->cart->get_coupons() as $code => $coupon ) : ?>
            <tr class="cart-discount coupon-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
                <th><?php wc_cart_totals_coupon_label( $coupon ); ?></th>
                <td data-title="<?php echo esc_attr( wc_cart_totals_coupon_label( $coupon, false ) ); ?>"><?php wc_cart_totals_coupon_html( $coupon ); ?></td>
            </tr>
		<?php endforeach; ?>

		<?php if ( wc()->cart->needs_shipping() && wc()->cart->show_shipping() ) : ?>

			<?php do_action( 'woocommerce_cart_totals_before_shipping' ); ?>

			<?php wc_cart_totals_shipping_html(); ?>

			<?php do_action( 'woocommerce_cart_totals_after_shipping' ); ?>

		<?php elseif ( wc()->cart->needs_shipping() && 'yes' === get_option( 'woocommerce_enable_shipping_calc' ) ) : ?>

            <tr class="shipping">
                <th><?php esc_html_e( 'Shipping', 'adamas' ); ?></th>
                <td data-title="<?php esc_attr_e( 'Shipping', 'adamas' ); ?>"><?php woocommerce_shipping_calculator(); ?></td>
            </tr>

		<?php endif; ?>

		<?php foreach ( wc()->cart->get_fees() as $fee ) : ?>
            <tr class="fee">
                <th><?php echo esc_html( $fee->name ); ?></th>
                <td data-title="<?php echo esc_attr( $fee->name ); ?>"><?php wc_cart_totals_fee_html( $fee ); ?></td>
            </tr>
		<?php endforeach; ?>

		<?php if ( wc_tax_enabled() && 'excl' === wc()->cart->tax_display_cart ) :
			$taxable_address = wc()->customer->get_taxable_address();
			$estimated_text = wc()->customer->is_customer_outside_base() && ! wc()->customer->has_calculated_shipping()
				? sprintf( ' <small>(' . wp_kses_post( __( 'estimated for %s', 'adamas' ) ) . ')</small>', wc()->countries->estimated_for_prefix( $taxable_address[0] ) . wc()->countries->countries[ $taxable_address[0] ] )
				: '';

			if ( 'itemized' === get_option( 'woocommerce_tax_total_display' ) ) : ?>
				<?php foreach ( wc()->cart->get_tax_totals() as $code => $tax ) : ?>
                    <tr class="tax-rate tax-rate-<?php echo sanitize_title( $code ); ?>">
                        <th><?php echo esc_html( $tax->label ) . $estimated_text; ?></th>
                        <td data-title="<?php echo esc_attr( $tax->label ); ?>"><?php echo wp_kses_post( $tax->formatted_amount ); ?></td>
                    </tr>
				<?php endforeach; ?>
			<?php else : ?>
                <tr class="tax-total">
                    <th><?php echo esc_html( wc()->countries->tax_or_vat() ) . $estimated_text; ?></th>
                    <td data-title="<?php echo esc_attr( wc()->countries->tax_or_vat() ); ?>"><?php wc_cart_totals_taxes_total_html(); ?></td>
                </tr>
			<?php endif; ?>
		<?php endif; ?>

		<?php do_action( 'woocommerce_cart_totals_before_order_total' ); ?>

        <tr class="order-total">
            <th><?php esc_html_e( 'Total', 'adamas' ); ?></th>
            <td data-title="<?php esc_attr_e( 'Total', 'adamas' ); ?>"><?php wc_cart_totals_order_total_html(); ?></td>
        </tr>

		<?php do_action( 'woocommerce_cart_totals_after_order_total' ); ?>

    </table>

    <div class="wc-proceed-to-checkout">
		<?php do_action( 'woocommerce_proceed_to_checkout' ); ?>
    </div>

	<?php do_action( 'woocommerce_after_cart_totals' ); ?>

</div>
